"use strict";

var _react = _interopRequireDefault(require("react"));
var _button = _interopRequireDefault(require("./button"));
var _reactNative = require("@testing-library/react-native");
var _themeContext = require("../../../theme/src/theme-context");
var _icon = _interopRequireDefault(require("../../atoms/icon/icon"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
jest.useFakeTimers();
describe("Molecules/Button", () => {
  it("passes the snapshot test for basic setup", async () => {
    const onPress = jest.fn();
    const tree = await (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_themeContext.ThemeProvider, null, /*#__PURE__*/_react.default.createElement(_button.default, {
      onPress: onPress
    }, "Button press"))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test for different sizes", async () => {
    const onPress = jest.fn();
    const tree = await (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_themeContext.ThemeProvider, null, /*#__PURE__*/_react.default.createElement(_button.default, {
      onPress: onPress,
      size: "xs"
    }, "Button press"), /*#__PURE__*/_react.default.createElement(_button.default, {
      onPress: onPress,
      size: "s"
    }, "Button press"), /*#__PURE__*/_react.default.createElement(_button.default, {
      onPress: onPress,
      size: "m"
    }, "Button press"), /*#__PURE__*/_react.default.createElement(_button.default, {
      onPress: onPress,
      size: "l"
    }, "Button press"))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test for different variants", async () => {
    const onPress = jest.fn();
    const tree = await (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_themeContext.ThemeProvider, null, /*#__PURE__*/_react.default.createElement(_button.default, {
      onPress: onPress,
      variant: "filled"
    }, "Button press"), /*#__PURE__*/_react.default.createElement(_button.default, {
      onPress: onPress,
      variant: "outline"
    }, "Button press"), /*#__PURE__*/_react.default.createElement(_button.default, {
      onPress: onPress,
      variant: "ghost"
    }, "Button press"))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test for different icons", async () => {
    const tree = await (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_themeContext.ThemeProvider, null, /*#__PURE__*/_react.default.createElement(_button.default, {
      leftIcon: /*#__PURE__*/_react.default.createElement(_icon.default, {
        iconFamily: "AntDesign",
        iconName: "heart"
      })
    }, "Button with left icon"), /*#__PURE__*/_react.default.createElement(_button.default, {
      variant: "outline",
      rightIcon: /*#__PURE__*/_react.default.createElement(_icon.default, {
        iconFamily: "AntDesign",
        iconName: "cloudupload"
      })
    }, "Button with right icon"))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test for loading state", async () => {
    const tree = await (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_themeContext.ThemeProvider, null, /*#__PURE__*/_react.default.createElement(_button.default, {
      isLoading: true
    }, "Basic loading button"), /*#__PURE__*/_react.default.createElement(_button.default, {
      isLoading: true,
      loadingText: "Loading"
    }, "Button with loading text"), /*#__PURE__*/_react.default.createElement(_button.default, {
      isLoading: true,
      loadingText: "Loading",
      spinnerPlacement: "end"
    }, "Button with spinner at the end"))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test for different color schemes", async () => {
    const tree = await (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_themeContext.ThemeProvider, null, /*#__PURE__*/_react.default.createElement(_button.default, {
      colorScheme: "primary"
    }, "Primary button"), /*#__PURE__*/_react.default.createElement(_button.default, {
      colorScheme: "secondary"
    }, "Secondary button"))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test when using style props", async () => {
    const onPress = jest.fn();
    const tree = await (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_themeContext.ThemeProvider, null, /*#__PURE__*/_react.default.createElement(_button.default, {
      onPress: onPress,
      backgroundColor: "primary.500",
      borderColor: "neutral.400",
      borderWidth: 2
    }, "Button press"))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("captures the onPress event", async () => {
    const onPress = jest.fn();
    const component = await (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_themeContext.ThemeProvider, null, /*#__PURE__*/_react.default.createElement(_button.default, {
      onPress: onPress,
      testID: "testOnPress"
    }, "Button press")));
    const tree = component.toJSON();
    if (tree.children[0].type !== "RNGestureHandlerButton") {
      const pressableInstance = component.getByTestId("testOnPress");
      _reactNative.fireEvent.press(pressableInstance);
      expect(onPress).toHaveBeenCalledTimes(1);
    }
  });
  it("doesn't capture the onPress event when the button is disabled ", async () => {
    const onPress = jest.fn();
    const component = await (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_themeContext.ThemeProvider, null, /*#__PURE__*/_react.default.createElement(_button.default, {
      onPress: onPress,
      isDisabled: true,
      testID: "testOnPress"
    }, "Button press")));
    const tree = component.toJSON();
    if (tree.children[0].type !== "RNGestureHandlerButton") {
      const pressableInstance = component.getByTestId("testOnPress");
      _reactNative.fireEvent.press(pressableInstance);
      expect(onPress).toHaveBeenCalledTimes(0);
    }
  });
  it("doesn't capture the onPress event when the button is in loading state ", async () => {
    const onPress = jest.fn();
    const component = await (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_themeContext.ThemeProvider, null, /*#__PURE__*/_react.default.createElement(_button.default, {
      onPress: onPress,
      isLoading: true,
      testID: "testOnPress"
    }, "Button press")));
    const tree = component.toJSON();
    if (tree.children[0].type !== "RNGestureHandlerButton") {
      const pressableInstance = component.getByTestId("testOnPress");
      _reactNative.fireEvent.press(pressableInstance);
      expect(onPress).toHaveBeenCalledTimes(0);
    }
  });
});
//# sourceMappingURL=button.spec.js.map