import React from "react";
import Button from "./button";
import { fireEvent, render } from "@testing-library/react-native";
import { ThemeProvider } from "../../../theme/src/theme-context";
import Icon from "../../atoms/icon/icon";
jest.useFakeTimers();
describe("Molecules/Button", () => {
  it("passes the snapshot test for basic setup", async () => {
    const onPress = jest.fn();
    const tree = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(Button, {
      onPress: onPress
    }, "Button press"))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test for different sizes", async () => {
    const onPress = jest.fn();
    const tree = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(Button, {
      onPress: onPress,
      size: "xs"
    }, "Button press"), /*#__PURE__*/React.createElement(Button, {
      onPress: onPress,
      size: "s"
    }, "Button press"), /*#__PURE__*/React.createElement(Button, {
      onPress: onPress,
      size: "m"
    }, "Button press"), /*#__PURE__*/React.createElement(Button, {
      onPress: onPress,
      size: "l"
    }, "Button press"))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test for different variants", async () => {
    const onPress = jest.fn();
    const tree = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(Button, {
      onPress: onPress,
      variant: "filled"
    }, "Button press"), /*#__PURE__*/React.createElement(Button, {
      onPress: onPress,
      variant: "outline"
    }, "Button press"), /*#__PURE__*/React.createElement(Button, {
      onPress: onPress,
      variant: "ghost"
    }, "Button press"))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test for different icons", async () => {
    const tree = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(Button, {
      leftIcon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      })
    }, "Button with left icon"), /*#__PURE__*/React.createElement(Button, {
      variant: "outline",
      rightIcon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "cloudupload"
      })
    }, "Button with right icon"))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test for loading state", async () => {
    const tree = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(Button, {
      isLoading: true
    }, "Basic loading button"), /*#__PURE__*/React.createElement(Button, {
      isLoading: true,
      loadingText: "Loading"
    }, "Button with loading text"), /*#__PURE__*/React.createElement(Button, {
      isLoading: true,
      loadingText: "Loading",
      spinnerPlacement: "end"
    }, "Button with spinner at the end"))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test for different color schemes", async () => {
    const tree = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(Button, {
      colorScheme: "primary"
    }, "Primary button"), /*#__PURE__*/React.createElement(Button, {
      colorScheme: "secondary"
    }, "Secondary button"))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test when using style props", async () => {
    const onPress = jest.fn();
    const tree = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(Button, {
      onPress: onPress,
      backgroundColor: "primary.500",
      borderColor: "neutral.400",
      borderWidth: 2
    }, "Button press"))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("captures the onPress event", async () => {
    const onPress = jest.fn();
    const component = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(Button, {
      onPress: onPress,
      testID: "testOnPress"
    }, "Button press")));
    const tree = component.toJSON();
    if (tree.children[0].type !== "RNGestureHandlerButton") {
      const pressableInstance = component.getByTestId("testOnPress");
      fireEvent.press(pressableInstance);
      expect(onPress).toHaveBeenCalledTimes(1);
    }
  });
  it("doesn't capture the onPress event when the button is disabled ", async () => {
    const onPress = jest.fn();
    const component = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(Button, {
      onPress: onPress,
      isDisabled: true,
      testID: "testOnPress"
    }, "Button press")));
    const tree = component.toJSON();
    if (tree.children[0].type !== "RNGestureHandlerButton") {
      const pressableInstance = component.getByTestId("testOnPress");
      fireEvent.press(pressableInstance);
      expect(onPress).toHaveBeenCalledTimes(0);
    }
  });
  it("doesn't capture the onPress event when the button is in loading state ", async () => {
    const onPress = jest.fn();
    const component = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(Button, {
      onPress: onPress,
      isLoading: true,
      testID: "testOnPress"
    }, "Button press")));
    const tree = component.toJSON();
    if (tree.children[0].type !== "RNGestureHandlerButton") {
      const pressableInstance = component.getByTestId("testOnPress");
      fireEvent.press(pressableInstance);
      expect(onPress).toHaveBeenCalledTimes(0);
    }
  });
});
//# sourceMappingURL=button.spec.js.map