import React from "react";
import IconButton from "./icon-button";
import { fireEvent, render } from "@testing-library/react-native";
import { ThemeProvider } from "../../../theme/src/theme-context";
import Icon from "../../atoms/icon/icon";
jest.useFakeTimers();
describe("Molecules/IconButton", () => {
  it("passes the snapshot test for basic setup", async () => {
    const onPress = jest.fn();
    const tree = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(IconButton, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      }),
      onPress: onPress
    }))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test for different sizes", async () => {
    const onPress = jest.fn();
    const tree = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(IconButton, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      }),
      onPress: onPress,
      size: "xs"
    }), /*#__PURE__*/React.createElement(IconButton, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      }),
      onPress: onPress,
      size: "s"
    }), /*#__PURE__*/React.createElement(IconButton, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      }),
      onPress: onPress,
      size: "m"
    }), /*#__PURE__*/React.createElement(IconButton, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      }),
      onPress: onPress,
      size: "l"
    }))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test for different variants", async () => {
    const onPress = jest.fn();
    const tree = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(IconButton, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      }),
      onPress: onPress,
      variant: "filled"
    }), /*#__PURE__*/React.createElement(IconButton, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      }),
      onPress: onPress,
      variant: "outline"
    }), /*#__PURE__*/React.createElement(IconButton, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      }),
      onPress: onPress,
      variant: "ghost"
    }))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test for different icons", async () => {
    const tree = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(IconButton, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      })
    }), /*#__PURE__*/React.createElement(IconButton, {
      variant: "outline",
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "cloudupload"
      })
    }))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test for loading state", async () => {
    const tree = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(IconButton, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      }),
      isLoading: true
    }, "Basic loading IconButton"))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test for different color schemes", async () => {
    const tree = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(IconButton, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      }),
      colorScheme: "primary"
    }), /*#__PURE__*/React.createElement(IconButton, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      }),
      colorScheme: "secondary"
    }))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("passes the snapshot test when using style props", async () => {
    const onPress = jest.fn();
    const tree = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(IconButton, {
      onPress: onPress,
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      }),
      backgroundColor: "primary.500",
      borderColor: "neutral.400",
      borderWidth: 2
    }))).toJSON();
    expect(tree).toMatchSnapshot();
  });
  it("captures the onPress event", async () => {
    const onPress = jest.fn();
    const component = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(IconButton, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      }),
      onPress: onPress,
      testID: "testOnPress"
    })));
    const tree = component.toJSON();
    if (tree.children[0].type !== "RNGestureHandlerButton") {
      const pressableInstance = component.getByTestId("testOnPress");
      fireEvent.press(pressableInstance);
      expect(onPress).toHaveBeenCalledTimes(1);
    }
  });
  it("doesn't capture the onPress event when the button is disabled ", async () => {
    const onPress = jest.fn();
    const component = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(IconButton, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      }),
      onPress: onPress,
      isDisabled: true,
      testID: "testOnPress"
    })));
    const tree = component.toJSON();
    if (tree.children[0].type !== "RNGestureHandlerButton") {
      const pressableInstance = component.getByTestId("testOnPress");
      fireEvent.press(pressableInstance);
      expect(onPress).toHaveBeenCalledTimes(0);
    }
  });
  it("doesn't capture the onPress event when the button is in loading state ", async () => {
    const onPress = jest.fn();
    const component = await render( /*#__PURE__*/React.createElement(ThemeProvider, null, /*#__PURE__*/React.createElement(IconButton, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        iconFamily: "AntDesign",
        iconName: "heart"
      }),
      onPress: onPress,
      isLoading: true,
      testID: "testOnPress"
    })));
    const tree = component.toJSON();
    if (tree.children[0].type !== "RNGestureHandlerButton") {
      const pressableInstance = component.getByTestId("testOnPress");
      fireEvent.press(pressableInstance);
      expect(onPress).toHaveBeenCalledTimes(0);
    }
  });
});
//# sourceMappingURL=icon-button.spec.js.map