import React from "react";
import { FinalPearlTheme, ResponsiveValue } from "../../../theme/src/types";
import { BoxProps } from "../box/box";
export type StackProps = BoxProps & {
    /**
     * The direction to stack the items
     *
     * @default "vertical"
     */
    direction?: "horizontal" | "vertical";
    /**
     * The spacing between the elements
     *
     * @default 2
     */
    spacing?: ResponsiveValue<keyof FinalPearlTheme["spacing"]>;
    /** If specified, each stack item will show the provided divider */
    divider?: React.ReactElement;
};
export type ZStackProps = BoxProps & {
    /**
     * The spacing between the elements
     *
     * @default 2
     */
    spacing?: ResponsiveValue<keyof FinalPearlTheme["spacing"]>;
    /**
     * Specifies the stacking order of the provided elements
     *
     * @default false
     */
    reversed?: boolean;
};
/**
 * Stack is a layout component that makes it easy to stack elements together and apply a space between them.
 */
declare const Stack: React.MemoExoticComponent<React.ForwardRefExoticComponent<Omit<StackProps, "ref"> & React.RefAttributes<unknown>>>;
/**
 * HStack is a layout component that stacks elements horizontally and apply a space between them.
 */
export declare const HStack: React.MemoExoticComponent<React.ForwardRefExoticComponent<Omit<Omit<StackProps, "direction">, "ref"> & React.RefAttributes<unknown>>>;
/**
 * VStack is a layout component that stacks elements vertically and apply a space between them.
 */
export declare const VStack: React.MemoExoticComponent<React.ForwardRefExoticComponent<Omit<Omit<StackProps, "direction">, "ref"> & React.RefAttributes<unknown>>>;
/**
 * ZStack is a layout component that stacks elements on top of each other.
 */
export declare const ZStack: React.MemoExoticComponent<React.ForwardRefExoticComponent<Omit<Omit<ZStackProps, "direction">, "ref"> & React.RefAttributes<unknown>>>;
export default Stack;
//# sourceMappingURL=stack.d.ts.map