import React from "react";
import { ImageProps } from "../image/image";
import { MoleculeComponentProps } from "../../../theme/src/types";
export type BaseAvatarProps = Omit<ImageProps, "source" | "size" | "variant"> & {
    /** The name of the person in the avatar.  If 'src' is not loaded or is missing, the 'name' will be used to create the initials */
    name?: string;
    /** The source of the Avatar image. This can be a url, or a local image */
    src?: string | number;
    /** A method to specify how initials are generated from a user's name */
    getInitials?(name: string): string;
    /** A custom list of background colors to choose the avatar background from.
     *
     * @default
     * [
        "#c8e6d0ff",
        "#e0ecbaff",
        "#fbb991ff",
        "#f27e81ff",
        "#8bc7d3ff",
        "#bcdfd8ff",
        "#fae3d9ff",
        "#f8b4b9ff",
        "#c2b0d7ff",
        "#eeef99ff",
        "#a5d7c4ff",
        "#fef5aeff",
        "#f7bdd6ff",
        "#d6a5cbff",
        "#c38788ff",
        "#FA8072",
        "#FFD700",
        "#FFA500",
      ]
     */
    customBackgroundColors?: string[];
};
/** The Avatar component is used to represent a user, and displays the profile picture, initials or fallback icon. */
declare const Avatar: React.ForwardRefExoticComponent<Omit<Omit<MoleculeComponentProps<"Avatar", BaseAvatarProps>, "atoms"> & {
    atoms?: Record<string, any> | undefined;
}, "ref"> & React.RefAttributes<unknown>>;
export type AvatarProps = React.ComponentProps<typeof Avatar>;
export default Avatar;
//# sourceMappingURL=avatar.d.ts.map