import React from "react";
import { BadgeProps } from "./badge";
export interface WithBadgeOptions {
    /**
     * The position of the badge with respect to the provided base component
     *
     * @default "topRight"
     */
    placement?: "topLeft" | "topRight" | "bottomLeft" | "bottomRight";
    /**
     * Amount of extra spacing to add between the badge and the base component
     *
     * @default 5
     */
    offset?: number;
    /**
     * Whether the badge is visible or not
     *
     * @default false
     */
    hidden?: boolean;
}
/**
 * A higher-order component which can be used to add a badge to any target component.
 * @param badgeValue The value to be displayed inside the badge
 * @param options A set of options for customizing the look of the badge
 * @returns
 */
declare const withBadge: <P extends {}>(badgeValue?: string | number | React.ReactElement | undefined, options?: WithBadgeOptions & BadgeProps) => (WrappedComponent: React.FC<P>) => (props: P) => React.ReactElement<P, string | React.JSXElementConstructor<any>>;
export default withBadge;
//# sourceMappingURL=withBadge.d.ts.map