import React from "react";
import { FinalPearlTheme, ResponsiveValue, MoleculeComponentProps, StateProps } from "../../../theme/src/types";
import { PressableProps } from "../../atoms/pressable/pressable";
import { RadioAtoms } from "./radio.config";
export type RadioProps = PressableProps & StateProps<"_checked" | "_invalid" | "_disabled"> & {
    /** Value of the radio if it is part of a group. */
    value?: string | number | undefined;
    /**
     * Whether the radio is disabled.
     *
     * @default false
     */
    isDisabled?: boolean;
    /**
     * Whether the radio is in a checked state.
     *
     * @default false
     */
    isChecked?: boolean;
    /**
     * Whether the radio is in an error state.
     *
     * @default false
     */
    isInvalid?: boolean;
    /**
     * The spacing between the radio and the label text.
     *
     * @default 2
     */
    spacing?: ResponsiveValue<keyof FinalPearlTheme["spacing"]>;
    children?: string;
};
/** The Radio component is used when only one choice may be selected in a series of options. **/
declare const Radio: React.MemoExoticComponent<React.ForwardRefExoticComponent<Omit<Omit<MoleculeComponentProps<"Radio", RadioProps, RadioAtoms>, "atoms"> & {
    atoms?: RadioAtoms | undefined;
}, "ref"> & React.RefAttributes<unknown>>>;
export default Radio;
//# sourceMappingURL=radio.d.ts.map