/// <reference types="react" />
import { ComponentTypes, StyleFunctionContainer } from "../../theme/src/types";
/**
 * Hook to manage a focused state and compose extra styling while a component is invalid
 * @param props The props object of a component
 * @param styleFunctions List of style functions supported by the component. By default, boxStyleFunctions are used
 * @param activeComponentType Type of the component inside which the hook is used. By default, this value is set to 'basic'
 * @param animateable Whether the styles should be dynamically animated using Moti. By default, this value is set to 'true'
 * @param parentStateValue A override value to control the 'invalid' state instead of the local state value
 * @returns The props object with updated styles according the current 'invalid' state
 */
export declare const useInvalidState: (props: Record<string, any>, styleFunctions?: StyleFunctionContainer[], activeComponentType?: ComponentTypes, animateable?: boolean, parentStateValue?: boolean | undefined) => {
    invalid: boolean;
    setInvalid: import("react").Dispatch<import("react").SetStateAction<boolean>>;
    propsWithInvalidStyles: Record<string, any>;
};
//# sourceMappingURL=useInvalidState.d.ts.map