import { AtLeastOneResponsiveValue, FinalPearlTheme, Dimensions, PropValue, ResponsiveValue } from "./types";
/**
 * Returns the value of a responsive object for the current screen size.
 * @param responsiveValue - The responsive object to get the value from.
 * @param breakpoints - The breakpoints object from the theme.
 * @param dimensions - The dimensions object containing the current scree n width and height.
 * @returns The value of the responsive object for the current screen size.
 */
export declare const getValueForScreenSize: <T extends PropValue = PropValue>({ responsiveValue, breakpoints, dimensions, }: {
    responsiveValue: AtLeastOneResponsiveValue<T>;
    breakpoints: FinalPearlTheme["breakpoints"];
    dimensions: Dimensions;
}) => PropValue;
/**
 * Determines whether a value is a responsive object value.
 * @param val - The value to check.
 * @param theme - The theme object.
 * @returns Whether the value is a responsive object value.
 */
export declare const isResponsiveObjectValue: (val: ResponsiveValue<PropValue>, theme: FinalPearlTheme) => val is AtLeastOneResponsiveValue;
//# sourceMappingURL=responsive-helpers.d.ts.map