/// <reference types="react-native-reanimated" />
import React from "react";
import { BoxProps } from "../box/box";
import { ResponsiveValue, PaletteColors } from "../../../theme";
type BaseSkeletonProps = BoxProps & {
    /**
     * The color at the animation start
     */
    startColor?: ResponsiveValue<PaletteColors>;
    /**
     * The color at the animation end
     */
    endColor?: ResponsiveValue<PaletteColors>;
    /**
     * If `true`, it'll render its children with a fade transition
     *
     * @default false
     */
    isLoaded?: boolean;
    /**
     * The animation speed in milliseconds
     *
     * @default 800
     */
    speed?: number;
    /**
     * The fadeIn duration in milliseconds. Requires `isLoaded` toggled to `true` in order to see the transition.
     *
     * @default 200
     */
    fadeDuration?: number;
};
/**
 * A Skeleton component that is used to show placeholders is a loading state
 */
declare const Skeleton: React.MemoExoticComponent<React.ForwardRefExoticComponent<Omit<import("../../../theme").BackgroundColorProps & import("../../../theme").OpacityProps & import("../../../theme").VisibleProps & {
    width?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    height?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    minWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    maxWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    minHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    maxHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    overflow?: ResponsiveValue<"scroll" | "visible" | "hidden" | undefined>;
    aspectRatio?: ResponsiveValue<string | number | undefined>;
    alignContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>;
    alignItems?: ResponsiveValue<import("react-native").FlexAlignType | undefined>;
    alignSelf?: ResponsiveValue<"auto" | import("react-native").FlexAlignType | undefined>;
    justifyContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>;
    flex?: ResponsiveValue<number | undefined>;
    flexBasis?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    flexDirection?: ResponsiveValue<"row" | "column" | "row-reverse" | "column-reverse" | undefined>;
    flexGrow?: ResponsiveValue<number | undefined>;
    flexShrink?: ResponsiveValue<number | undefined>;
    flexWrap?: ResponsiveValue<"wrap" | "nowrap" | "wrap-reverse" | undefined>;
} & {
    readonly w?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    readonly h?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    readonly minW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    readonly maxW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    readonly minH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    readonly maxH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
} & import("../../../theme").TransformProps & {
    margin?: ResponsiveValue<string | number> | undefined;
    marginTop?: ResponsiveValue<string | number> | undefined;
    marginRight?: ResponsiveValue<string | number> | undefined;
    marginBottom?: ResponsiveValue<string | number> | undefined;
    marginLeft?: ResponsiveValue<string | number> | undefined;
    marginHorizontal?: ResponsiveValue<string | number> | undefined;
    marginVertical?: ResponsiveValue<string | number> | undefined;
    marginStart?: ResponsiveValue<string | number> | undefined;
    marginEnd?: ResponsiveValue<string | number> | undefined;
    padding?: ResponsiveValue<string | number> | undefined;
    paddingTop?: ResponsiveValue<string | number> | undefined;
    paddingRight?: ResponsiveValue<string | number> | undefined;
    paddingBottom?: ResponsiveValue<string | number> | undefined;
    paddingLeft?: ResponsiveValue<string | number> | undefined;
    paddingHorizontal?: ResponsiveValue<string | number> | undefined;
    paddingVertical?: ResponsiveValue<string | number> | undefined;
    paddingStart?: ResponsiveValue<string | number> | undefined;
    paddingEnd?: ResponsiveValue<string | number> | undefined;
} & {
    readonly m?: ResponsiveValue<string | number> | undefined;
    readonly mt?: ResponsiveValue<string | number> | undefined;
    readonly mr?: ResponsiveValue<string | number> | undefined;
    readonly mb?: ResponsiveValue<string | number> | undefined;
    readonly ml?: ResponsiveValue<string | number> | undefined;
    readonly mx?: ResponsiveValue<string | number> | undefined;
    readonly my?: ResponsiveValue<string | number> | undefined;
    readonly ms?: ResponsiveValue<string | number> | undefined;
    readonly me?: ResponsiveValue<string | number> | undefined;
    readonly p?: ResponsiveValue<string | number> | undefined;
    readonly pt?: ResponsiveValue<string | number> | undefined;
    readonly pr?: ResponsiveValue<string | number> | undefined;
    readonly pb?: ResponsiveValue<string | number> | undefined;
    readonly pl?: ResponsiveValue<string | number> | undefined;
    readonly px?: ResponsiveValue<string | number> | undefined;
    readonly py?: ResponsiveValue<string | number> | undefined;
    readonly ps?: ResponsiveValue<string | number> | undefined;
    readonly pe?: ResponsiveValue<string | number> | undefined;
} & {
    borderBottomWidth?: ResponsiveValue<number | undefined>;
    borderLeftWidth?: ResponsiveValue<number | undefined>;
    borderRightWidth?: ResponsiveValue<number | undefined>;
    borderStyle?: ResponsiveValue<"solid" | "dotted" | "dashed" | undefined>;
    borderTopWidth?: ResponsiveValue<number | undefined>;
    borderStartWidth?: ResponsiveValue<number | undefined>;
    borderEndWidth?: ResponsiveValue<number | undefined>;
    borderWidth?: ResponsiveValue<number | undefined>;
} & {
    borderColor?: ResponsiveValue<PaletteColors> | undefined;
    borderTopColor?: ResponsiveValue<PaletteColors> | undefined;
    borderRightColor?: ResponsiveValue<PaletteColors> | undefined;
    borderLeftColor?: ResponsiveValue<PaletteColors> | undefined;
    borderBottomColor?: ResponsiveValue<PaletteColors> | undefined;
    borderStartColor?: ResponsiveValue<PaletteColors> | undefined;
    borderEndColor?: ResponsiveValue<PaletteColors> | undefined;
} & {
    borderRadius?: ResponsiveValue<string | number> | undefined;
    borderBottomLeftRadius?: ResponsiveValue<string | number> | undefined;
    borderBottomRightRadius?: ResponsiveValue<string | number> | undefined;
    borderTopLeftRadius?: ResponsiveValue<string | number> | undefined;
    borderTopRightRadius?: ResponsiveValue<string | number> | undefined;
    borderBottomStartRadius?: ResponsiveValue<string | number> | undefined;
    borderBottomEndRadius?: ResponsiveValue<string | number> | undefined;
    borderTopStartRadius?: ResponsiveValue<string | number> | undefined;
    borderTopEndRadius?: ResponsiveValue<string | number> | undefined;
} & {
    shadowOpacity?: ResponsiveValue<import("react-native").AnimatableNumericValue | undefined>;
    shadowOffset?: ResponsiveValue<Readonly<{
        width: number;
        height: number;
    }> | undefined>;
    shadowRadius?: ResponsiveValue<number | undefined>;
    elevation?: ResponsiveValue<number | undefined>;
} & {
    boxShadow?: ResponsiveValue<string | number> | undefined;
    shadowColor?: ResponsiveValue<PaletteColors> | undefined;
} & {
    position?: ResponsiveValue<"absolute" | "relative" | undefined>;
    top?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    right?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    bottom?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    left?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    start?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    end?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
} & {
    zIndex?: ResponsiveValue<string | number> | undefined;
} & Pick<import("react-native").ViewProps & {
    animatedProps?: Partial<import("react-native").ViewProps> | undefined;
    layout?: import("react-native-reanimated").BaseAnimationBuilder | import("react-native-reanimated").LayoutAnimationFunction | typeof import("react-native-reanimated").BaseAnimationBuilder | undefined;
    entering?: import("react-native-reanimated").BaseAnimationBuilder | typeof import("react-native-reanimated").BaseAnimationBuilder | import("react-native-reanimated").EntryExitAnimationFunction | Keyframe | undefined;
    exiting?: import("react-native-reanimated").BaseAnimationBuilder | typeof import("react-native-reanimated").BaseAnimationBuilder | import("react-native-reanimated").EntryExitAnimationFunction | Keyframe | undefined;
} & import("moti").MotiProps<import("react-native").ViewStyle | import("react-native").ImageStyle | import("react-native").TextStyle, import("moti").StyleValueWithReplacedTransforms<import("react-native").ViewStyle | import("react-native").ImageStyle | import("react-native").TextStyle>, Partial<{
    backfaceVisibility: "visible" | "hidden" | import("moti").SequenceItem<"visible" | "hidden" | undefined>[] | undefined;
    backgroundColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
    borderBottomLeftRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderBottomRightRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderBottomWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
    borderLeftWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderRightWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderTopLeftRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderTopRightRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderTopWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    opacity: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    alignContent: "center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>[] | undefined;
    alignItems: import("react-native").FlexAlignType | import("moti").SequenceItem<import("react-native").FlexAlignType | undefined>[] | undefined;
    alignSelf: "auto" | import("react-native").FlexAlignType | import("moti").SequenceItem<"auto" | import("react-native").FlexAlignType | undefined>[] | undefined;
    aspectRatio: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderEndWidth: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    borderStartWidth: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    bottom: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    display: "none" | "flex" | import("moti").SequenceItem<"none" | "flex" | undefined>[] | undefined;
    end: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    flex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    flexBasis: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    flexDirection: "row" | "column" | "row-reverse" | "column-reverse" | import("moti").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | undefined;
    flexGrow: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    flexShrink: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    flexWrap: "wrap" | "nowrap" | "wrap-reverse" | import("moti").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | undefined;
    height: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    justifyContent: "center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>[] | undefined;
    left: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    margin: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginBottom: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginEnd: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginHorizontal: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginLeft: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginRight: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginStart: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginTop: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginVertical: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    maxHeight: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    maxWidth: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    minHeight: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    minWidth: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    overflow: "scroll" | "visible" | "hidden" | import("moti").SequenceItem<"scroll" | "visible" | "hidden" | undefined>[] | undefined;
    padding: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingBottom: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingEnd: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingHorizontal: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingLeft: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingRight: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingStart: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingTop: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingVertical: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    position: "absolute" | "relative" | import("moti").SequenceItem<"absolute" | "relative" | undefined>[] | undefined;
    right: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    start: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    top: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    width: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    zIndex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    direction: "inherit" | "ltr" | "rtl" | import("moti").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | undefined;
    shadowColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
    shadowOffset: {
        width: number;
        height: number;
    } | import("moti").SequenceItem<{
        width: number;
        height: number;
    } | undefined>[] | undefined;
    shadowOpacity: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    shadowRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    transformMatrix: number[] | import("moti").SequenceItem<number[] | undefined>[] | undefined;
    rotation: number | import("moti").SequenceItem<number | undefined>[] | undefined;
} & {
    scaleX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined;
    scaleY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined;
    translateX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined;
    translateY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined;
    perspective?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined;
    rotate?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined;
    rotateX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined;
    rotateY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined;
    rotateZ?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined;
    scale?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined;
    skewX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined;
    skewY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined;
} & import("moti").StyleValueWithSequenceArraysWithTransform>, {
    backfaceVisibility?: "visible" | "hidden" | import("moti").SequenceItem<"visible" | "hidden" | undefined>[] | {
        value: "visible" | "hidden" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"visible" | "hidden" | import("moti").SequenceItem<"visible" | "hidden" | undefined>[] | undefined>;
    } | undefined;
    backgroundColor?: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | {
        value: import("react-native").ColorValue | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined>;
    } | undefined;
    borderBottomLeftRadius?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderBottomRightRadius?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderBottomWidth?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderColor?: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | {
        value: import("react-native").ColorValue | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined>;
    } | undefined;
    borderLeftWidth?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderRadius?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderRightWidth?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderTopLeftRadius?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderTopRightRadius?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderTopWidth?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderWidth?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    opacity?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    alignContent?: "center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>[] | {
        value: "center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>[] | undefined>;
    } | undefined;
    alignItems?: import("react-native").FlexAlignType | import("moti").SequenceItem<import("react-native").FlexAlignType | undefined>[] | {
        value: import("react-native").FlexAlignType | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<import("react-native").FlexAlignType | import("moti").SequenceItem<import("react-native").FlexAlignType | undefined>[] | undefined>;
    } | undefined;
    alignSelf?: "auto" | import("react-native").FlexAlignType | import("moti").SequenceItem<"auto" | import("react-native").FlexAlignType | undefined>[] | {
        value: "auto" | import("react-native").FlexAlignType | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"auto" | import("react-native").FlexAlignType | import("moti").SequenceItem<"auto" | import("react-native").FlexAlignType | undefined>[] | undefined>;
    } | undefined;
    aspectRatio?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderEndWidth?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    borderStartWidth?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    bottom?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    display?: "none" | "flex" | import("moti").SequenceItem<"none" | "flex" | undefined>[] | {
        value: "none" | "flex" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"none" | "flex" | import("moti").SequenceItem<"none" | "flex" | undefined>[] | undefined>;
    } | undefined;
    end?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    flex?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    flexBasis?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    flexDirection?: "row" | "column" | "row-reverse" | "column-reverse" | import("moti").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | {
        value: "row" | "column" | "row-reverse" | "column-reverse" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"row" | "column" | "row-reverse" | "column-reverse" | import("moti").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | undefined>;
    } | undefined;
    flexGrow?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    flexShrink?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    flexWrap?: "wrap" | "nowrap" | "wrap-reverse" | import("moti").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | {
        value: "wrap" | "nowrap" | "wrap-reverse" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"wrap" | "nowrap" | "wrap-reverse" | import("moti").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | undefined>;
    } | undefined;
    height?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    justifyContent?: "center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>[] | {
        value: "center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>[] | undefined>;
    } | undefined;
    left?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    margin?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginBottom?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginEnd?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginHorizontal?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginLeft?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginRight?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginStart?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginTop?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginVertical?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    maxHeight?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    maxWidth?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    minHeight?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    minWidth?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    overflow?: "scroll" | "visible" | "hidden" | import("moti").SequenceItem<"scroll" | "visible" | "hidden" | undefined>[] | {
        value: "scroll" | "visible" | "hidden" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"scroll" | "visible" | "hidden" | import("moti").SequenceItem<"scroll" | "visible" | "hidden" | undefined>[] | undefined>;
    } | undefined;
    padding?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingBottom?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingEnd?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingHorizontal?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingLeft?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingRight?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingStart?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingTop?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingVertical?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    position?: "absolute" | "relative" | import("moti").SequenceItem<"absolute" | "relative" | undefined>[] | {
        value: "absolute" | "relative" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"absolute" | "relative" | import("moti").SequenceItem<"absolute" | "relative" | undefined>[] | undefined>;
    } | undefined;
    right?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    start?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    top?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    width?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    zIndex?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    direction?: "inherit" | "ltr" | "rtl" | import("moti").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | {
        value: "inherit" | "ltr" | "rtl" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"inherit" | "ltr" | "rtl" | import("moti").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | undefined>;
    } | undefined;
    shadowColor?: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | {
        value: import("react-native").ColorValue | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined>;
    } | undefined;
    shadowOffset?: {
        width: number;
        height: number;
    } | import("moti").SequenceItem<{
        width: number;
        height: number;
    } | undefined>[] | {
        value: undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<{
            width: number;
            height: number;
        } | import("moti").SequenceItem<{
            width: number;
            height: number;
        } | undefined>[] | undefined>;
    } | undefined;
    shadowOpacity?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    shadowRadius?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    transformMatrix?: number[] | import("moti").SequenceItem<number[] | undefined>[] | {
        value: undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number[] | import("moti").SequenceItem<number[] | undefined>[] | undefined>;
    } | undefined;
    rotation?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    scaleX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    scaleY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    translateX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    translateY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    perspective?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    rotate?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | {
        value: string | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    rotateX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | {
        value: string | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    rotateY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | {
        value: string | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    rotateZ?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | {
        value: string | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    scale?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    skewX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | {
        value: string | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    skewY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | {
        value: string | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    transform?: Partial<{
        scaleX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
        scaleY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
        translateX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
        translateY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
        perspective?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
        rotate?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
        rotateX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
        rotateY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
        rotateZ?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
        scale?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
        skewX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
        skewY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
    } & import("moti").StyleValueWithSequenceArraysWithTransform>[] | {
        value: undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<Partial<{
            scaleX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
            scaleY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
            translateX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
            translateY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
            perspective?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
            rotate?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
            rotateX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
            rotateY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
            rotateZ?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
            scale?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
            skewX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
            skewY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
        } & import("moti").StyleValueWithSequenceArraysWithTransform>[] | undefined>;
    } | undefined;
}> & {
    children?: React.ReactNode;
} & React.RefAttributes<unknown>, "delay" | "stylePriority" | "onDidAnimate" | "animateInitialState"> & {
    from?: boolean | (Omit<Partial<{
        end: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        start: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        elevation: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        margin: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginTop: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginRight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginBottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginLeft: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginHorizontal: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginVertical: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginStart: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginEnd: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        padding: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingTop: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingRight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingBottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingLeft: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingHorizontal: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingVertical: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingStart: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingEnd: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        width: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        height: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        minWidth: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        maxWidth: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        minHeight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        maxHeight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        overflow: "scroll" | "visible" | "hidden" | import("moti").SequenceItem<"scroll" | "visible" | "hidden" | undefined>[] | undefined;
        aspectRatio: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
        alignContent: "center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>[] | undefined;
        alignItems: import("react-native").FlexAlignType | import("moti").SequenceItem<import("react-native").FlexAlignType | undefined>[] | undefined;
        alignSelf: "auto" | import("react-native").FlexAlignType | import("moti").SequenceItem<"auto" | import("react-native").FlexAlignType | undefined>[] | undefined;
        justifyContent: "center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>[] | undefined;
        flex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexBasis: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        flexDirection: "row" | "column" | "row-reverse" | "column-reverse" | import("moti").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | undefined;
        flexGrow: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexShrink: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexWrap: "wrap" | "nowrap" | "wrap-reverse" | import("moti").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | undefined;
        transformMatrix: number[] | import("moti").SequenceItem<number[] | undefined>[] | undefined;
        rotation: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        position: "absolute" | "relative" | import("moti").SequenceItem<"absolute" | "relative" | undefined>[] | undefined;
        top: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        right: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        bottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        left: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        borderBottomWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderLeftWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderRightWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderStyle: "solid" | "dotted" | "dashed" | import("moti").SequenceItem<"solid" | "dotted" | "dashed" | undefined>[] | undefined;
        borderTopWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderStartWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderEndWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderTopColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderRightColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderLeftColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBottomColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderStartColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderEndColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomLeftRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomRightRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopLeftRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopRightRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        shadowOpacity: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        shadowOffset: Readonly<{
            width: number;
            height: number;
        }> | import("moti").SequenceItem<Readonly<{
            width: number;
            height: number;
        }> | undefined>[] | undefined;
        shadowRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        display: "none" | "flex" | import("moti").SequenceItem<"none" | "flex" | undefined>[] | undefined;
        backfaceVisibility: "visible" | "hidden" | import("moti").SequenceItem<"visible" | "hidden" | undefined>[] | undefined;
        backgroundColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockEndColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockStartColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderCurve: "circular" | "continuous" | import("moti").SequenceItem<"circular" | "continuous" | undefined>[] | undefined;
        borderEndEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderEndStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderStartEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderStartStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        opacity: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        pointerEvents: "auto" | "none" | "box-none" | "box-only" | import("moti").SequenceItem<"auto" | "none" | "box-none" | "box-only" | undefined>[] | undefined;
        rowGap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        gap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        columnGap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        zIndex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        direction: "inherit" | "ltr" | "rtl" | import("moti").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | undefined;
        shadowColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
    } & {
        scaleX?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        scaleY?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        translateX?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        translateY?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        perspective?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        rotate?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateX?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateY?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateZ?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        scale?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        skewX?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        skewY?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
    } & import("moti").StyleValueWithSequenceArraysWithTransform>, keyof import("react-native").ViewStyle> & Omit<import("react-native").ViewStyle, "p" | "ms" | "end" | "start" | "m" | "py" | "pl" | "elevation" | "margin" | "marginTop" | "marginRight" | "marginBottom" | "marginLeft" | "marginHorizontal" | "marginVertical" | "marginStart" | "marginEnd" | "padding" | "paddingTop" | "paddingRight" | "paddingBottom" | "paddingLeft" | "paddingHorizontal" | "paddingVertical" | "paddingStart" | "paddingEnd" | "width" | "height" | "minWidth" | "maxWidth" | "minHeight" | "maxHeight" | "mt" | "mr" | "mb" | "ml" | "mx" | "my" | "me" | "pt" | "pr" | "pb" | "px" | "ps" | "pe" | "overflow" | "aspectRatio" | "alignContent" | "alignItems" | "alignSelf" | "justifyContent" | "flex" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "w" | "h" | "minW" | "maxW" | "minH" | "maxH" | "transform" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "position" | "top" | "right" | "bottom" | "left" | "borderBottomWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStyle" | "borderTopWidth" | "borderStartWidth" | "borderEndWidth" | "borderWidth" | "borderColor" | "borderTopColor" | "borderRightColor" | "borderLeftColor" | "borderBottomColor" | "borderStartColor" | "borderEndColor" | "borderRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderBottomStartRadius" | "borderBottomEndRadius" | "borderTopStartRadius" | "borderTopEndRadius" | "shadowOpacity" | "shadowOffset" | "shadowRadius" | "opacity" | "zIndex" | "shadowColor" | keyof import("../../../theme").BackgroundColorProps | "visible" | "boxShadow"> & import("../../../theme").BackgroundColorProps & import("../../../theme").OpacityProps & import("../../../theme").VisibleProps & {
        width?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        height?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        overflow?: ResponsiveValue<"scroll" | "visible" | "hidden" | undefined>;
        aspectRatio?: ResponsiveValue<string | number | undefined>;
        alignContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>;
        alignItems?: ResponsiveValue<import("react-native").FlexAlignType | undefined>;
        alignSelf?: ResponsiveValue<"auto" | import("react-native").FlexAlignType | undefined>;
        justifyContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>;
        flex?: ResponsiveValue<number | undefined>;
        flexBasis?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        flexDirection?: ResponsiveValue<"row" | "column" | "row-reverse" | "column-reverse" | undefined>;
        flexGrow?: ResponsiveValue<number | undefined>;
        flexShrink?: ResponsiveValue<number | undefined>;
        flexWrap?: ResponsiveValue<"wrap" | "nowrap" | "wrap-reverse" | undefined>;
    } & {
        readonly w?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly h?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & import("../../../theme").TransformProps & {
        margin?: ResponsiveValue<string | number> | undefined;
        marginTop?: ResponsiveValue<string | number> | undefined;
        marginRight?: ResponsiveValue<string | number> | undefined;
        marginBottom?: ResponsiveValue<string | number> | undefined;
        marginLeft?: ResponsiveValue<string | number> | undefined;
        marginHorizontal?: ResponsiveValue<string | number> | undefined;
        marginVertical?: ResponsiveValue<string | number> | undefined;
        marginStart?: ResponsiveValue<string | number> | undefined;
        marginEnd?: ResponsiveValue<string | number> | undefined;
        padding?: ResponsiveValue<string | number> | undefined;
        paddingTop?: ResponsiveValue<string | number> | undefined;
        paddingRight?: ResponsiveValue<string | number> | undefined;
        paddingBottom?: ResponsiveValue<string | number> | undefined;
        paddingLeft?: ResponsiveValue<string | number> | undefined;
        paddingHorizontal?: ResponsiveValue<string | number> | undefined;
        paddingVertical?: ResponsiveValue<string | number> | undefined;
        paddingStart?: ResponsiveValue<string | number> | undefined;
        paddingEnd?: ResponsiveValue<string | number> | undefined;
    } & {
        readonly m?: ResponsiveValue<string | number> | undefined;
        readonly mt?: ResponsiveValue<string | number> | undefined;
        readonly mr?: ResponsiveValue<string | number> | undefined;
        readonly mb?: ResponsiveValue<string | number> | undefined;
        readonly ml?: ResponsiveValue<string | number> | undefined;
        readonly mx?: ResponsiveValue<string | number> | undefined;
        readonly my?: ResponsiveValue<string | number> | undefined;
        readonly ms?: ResponsiveValue<string | number> | undefined;
        readonly me?: ResponsiveValue<string | number> | undefined;
        readonly p?: ResponsiveValue<string | number> | undefined;
        readonly pt?: ResponsiveValue<string | number> | undefined;
        readonly pr?: ResponsiveValue<string | number> | undefined;
        readonly pb?: ResponsiveValue<string | number> | undefined;
        readonly pl?: ResponsiveValue<string | number> | undefined;
        readonly px?: ResponsiveValue<string | number> | undefined;
        readonly py?: ResponsiveValue<string | number> | undefined;
        readonly ps?: ResponsiveValue<string | number> | undefined;
        readonly pe?: ResponsiveValue<string | number> | undefined;
    } & {
        borderBottomWidth?: ResponsiveValue<number | undefined>;
        borderLeftWidth?: ResponsiveValue<number | undefined>;
        borderRightWidth?: ResponsiveValue<number | undefined>;
        borderStyle?: ResponsiveValue<"solid" | "dotted" | "dashed" | undefined>;
        borderTopWidth?: ResponsiveValue<number | undefined>;
        borderStartWidth?: ResponsiveValue<number | undefined>;
        borderEndWidth?: ResponsiveValue<number | undefined>;
        borderWidth?: ResponsiveValue<number | undefined>;
    } & {
        borderColor?: ResponsiveValue<PaletteColors> | undefined;
        borderTopColor?: ResponsiveValue<PaletteColors> | undefined;
        borderRightColor?: ResponsiveValue<PaletteColors> | undefined;
        borderLeftColor?: ResponsiveValue<PaletteColors> | undefined;
        borderBottomColor?: ResponsiveValue<PaletteColors> | undefined;
        borderStartColor?: ResponsiveValue<PaletteColors> | undefined;
        borderEndColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        borderRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomRightRadius?: ResponsiveValue<string | number> | undefined;
        borderTopLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderTopRightRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomStartRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomEndRadius?: ResponsiveValue<string | number> | undefined;
        borderTopStartRadius?: ResponsiveValue<string | number> | undefined;
        borderTopEndRadius?: ResponsiveValue<string | number> | undefined;
    } & {
        shadowOpacity?: ResponsiveValue<import("react-native").AnimatableNumericValue | undefined>;
        shadowOffset?: ResponsiveValue<Readonly<{
            width: number;
            height: number;
        }> | undefined>;
        shadowRadius?: ResponsiveValue<number | undefined>;
        elevation?: ResponsiveValue<number | undefined>;
    } & {
        boxShadow?: ResponsiveValue<string | number> | undefined;
        shadowColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        position?: ResponsiveValue<"absolute" | "relative" | undefined>;
        top?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        right?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        bottom?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        left?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        start?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        end?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & {
        zIndex?: ResponsiveValue<string | number> | undefined;
    }) | undefined;
    animate?: ((Omit<Partial<{
        end: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        start: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        elevation: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        margin: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginTop: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginRight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginBottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginLeft: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginHorizontal: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginVertical: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginStart: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginEnd: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        padding: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingTop: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingRight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingBottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingLeft: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingHorizontal: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingVertical: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingStart: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingEnd: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        width: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        height: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        minWidth: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        maxWidth: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        minHeight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        maxHeight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        overflow: "scroll" | "visible" | "hidden" | import("moti").SequenceItem<"scroll" | "visible" | "hidden" | undefined>[] | undefined;
        aspectRatio: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
        alignContent: "center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>[] | undefined;
        alignItems: import("react-native").FlexAlignType | import("moti").SequenceItem<import("react-native").FlexAlignType | undefined>[] | undefined;
        alignSelf: "auto" | import("react-native").FlexAlignType | import("moti").SequenceItem<"auto" | import("react-native").FlexAlignType | undefined>[] | undefined;
        justifyContent: "center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>[] | undefined;
        flex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexBasis: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        flexDirection: "row" | "column" | "row-reverse" | "column-reverse" | import("moti").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | undefined;
        flexGrow: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexShrink: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexWrap: "wrap" | "nowrap" | "wrap-reverse" | import("moti").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | undefined;
        transformMatrix: number[] | import("moti").SequenceItem<number[] | undefined>[] | undefined;
        rotation: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        position: "absolute" | "relative" | import("moti").SequenceItem<"absolute" | "relative" | undefined>[] | undefined;
        top: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        right: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        bottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        left: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        borderBottomWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderLeftWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderRightWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderStyle: "solid" | "dotted" | "dashed" | import("moti").SequenceItem<"solid" | "dotted" | "dashed" | undefined>[] | undefined;
        borderTopWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderStartWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderEndWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderTopColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderRightColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderLeftColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBottomColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderStartColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderEndColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomLeftRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomRightRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopLeftRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopRightRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        shadowOpacity: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        shadowOffset: Readonly<{
            width: number;
            height: number;
        }> | import("moti").SequenceItem<Readonly<{
            width: number;
            height: number;
        }> | undefined>[] | undefined;
        shadowRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        display: "none" | "flex" | import("moti").SequenceItem<"none" | "flex" | undefined>[] | undefined;
        backfaceVisibility: "visible" | "hidden" | import("moti").SequenceItem<"visible" | "hidden" | undefined>[] | undefined;
        backgroundColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockEndColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockStartColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderCurve: "circular" | "continuous" | import("moti").SequenceItem<"circular" | "continuous" | undefined>[] | undefined;
        borderEndEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderEndStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderStartEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderStartStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        opacity: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        pointerEvents: "auto" | "none" | "box-none" | "box-only" | import("moti").SequenceItem<"auto" | "none" | "box-none" | "box-only" | undefined>[] | undefined;
        rowGap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        gap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        columnGap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        zIndex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        direction: "inherit" | "ltr" | "rtl" | import("moti").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | undefined;
        shadowColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
    } & {
        scaleX?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        scaleY?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        translateX?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        translateY?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        perspective?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        rotate?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateX?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateY?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateZ?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        scale?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        skewX?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        skewY?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
    } & import("moti").StyleValueWithSequenceArraysWithTransform>, keyof import("react-native").ViewStyle> & Omit<import("react-native").ViewStyle, "p" | "ms" | "end" | "start" | "m" | "py" | "pl" | "elevation" | "margin" | "marginTop" | "marginRight" | "marginBottom" | "marginLeft" | "marginHorizontal" | "marginVertical" | "marginStart" | "marginEnd" | "padding" | "paddingTop" | "paddingRight" | "paddingBottom" | "paddingLeft" | "paddingHorizontal" | "paddingVertical" | "paddingStart" | "paddingEnd" | "width" | "height" | "minWidth" | "maxWidth" | "minHeight" | "maxHeight" | "mt" | "mr" | "mb" | "ml" | "mx" | "my" | "me" | "pt" | "pr" | "pb" | "px" | "ps" | "pe" | "overflow" | "aspectRatio" | "alignContent" | "alignItems" | "alignSelf" | "justifyContent" | "flex" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "w" | "h" | "minW" | "maxW" | "minH" | "maxH" | "transform" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "position" | "top" | "right" | "bottom" | "left" | "borderBottomWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStyle" | "borderTopWidth" | "borderStartWidth" | "borderEndWidth" | "borderWidth" | "borderColor" | "borderTopColor" | "borderRightColor" | "borderLeftColor" | "borderBottomColor" | "borderStartColor" | "borderEndColor" | "borderRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderBottomStartRadius" | "borderBottomEndRadius" | "borderTopStartRadius" | "borderTopEndRadius" | "shadowOpacity" | "shadowOffset" | "shadowRadius" | "opacity" | "zIndex" | "shadowColor" | keyof import("../../../theme").BackgroundColorProps | "visible" | "boxShadow"> & import("../../../theme").BackgroundColorProps & import("../../../theme").OpacityProps & import("../../../theme").VisibleProps & {
        width?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        height?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        overflow?: ResponsiveValue<"scroll" | "visible" | "hidden" | undefined>;
        aspectRatio?: ResponsiveValue<string | number | undefined>;
        alignContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>;
        alignItems?: ResponsiveValue<import("react-native").FlexAlignType | undefined>;
        alignSelf?: ResponsiveValue<"auto" | import("react-native").FlexAlignType | undefined>;
        justifyContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>;
        flex?: ResponsiveValue<number | undefined>;
        flexBasis?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        flexDirection?: ResponsiveValue<"row" | "column" | "row-reverse" | "column-reverse" | undefined>;
        flexGrow?: ResponsiveValue<number | undefined>;
        flexShrink?: ResponsiveValue<number | undefined>;
        flexWrap?: ResponsiveValue<"wrap" | "nowrap" | "wrap-reverse" | undefined>;
    } & {
        readonly w?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly h?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & import("../../../theme").TransformProps & {
        margin?: ResponsiveValue<string | number> | undefined;
        marginTop?: ResponsiveValue<string | number> | undefined;
        marginRight?: ResponsiveValue<string | number> | undefined;
        marginBottom?: ResponsiveValue<string | number> | undefined;
        marginLeft?: ResponsiveValue<string | number> | undefined;
        marginHorizontal?: ResponsiveValue<string | number> | undefined;
        marginVertical?: ResponsiveValue<string | number> | undefined;
        marginStart?: ResponsiveValue<string | number> | undefined;
        marginEnd?: ResponsiveValue<string | number> | undefined;
        padding?: ResponsiveValue<string | number> | undefined;
        paddingTop?: ResponsiveValue<string | number> | undefined;
        paddingRight?: ResponsiveValue<string | number> | undefined;
        paddingBottom?: ResponsiveValue<string | number> | undefined;
        paddingLeft?: ResponsiveValue<string | number> | undefined;
        paddingHorizontal?: ResponsiveValue<string | number> | undefined;
        paddingVertical?: ResponsiveValue<string | number> | undefined;
        paddingStart?: ResponsiveValue<string | number> | undefined;
        paddingEnd?: ResponsiveValue<string | number> | undefined;
    } & {
        readonly m?: ResponsiveValue<string | number> | undefined;
        readonly mt?: ResponsiveValue<string | number> | undefined;
        readonly mr?: ResponsiveValue<string | number> | undefined;
        readonly mb?: ResponsiveValue<string | number> | undefined;
        readonly ml?: ResponsiveValue<string | number> | undefined;
        readonly mx?: ResponsiveValue<string | number> | undefined;
        readonly my?: ResponsiveValue<string | number> | undefined;
        readonly ms?: ResponsiveValue<string | number> | undefined;
        readonly me?: ResponsiveValue<string | number> | undefined;
        readonly p?: ResponsiveValue<string | number> | undefined;
        readonly pt?: ResponsiveValue<string | number> | undefined;
        readonly pr?: ResponsiveValue<string | number> | undefined;
        readonly pb?: ResponsiveValue<string | number> | undefined;
        readonly pl?: ResponsiveValue<string | number> | undefined;
        readonly px?: ResponsiveValue<string | number> | undefined;
        readonly py?: ResponsiveValue<string | number> | undefined;
        readonly ps?: ResponsiveValue<string | number> | undefined;
        readonly pe?: ResponsiveValue<string | number> | undefined;
    } & {
        borderBottomWidth?: ResponsiveValue<number | undefined>;
        borderLeftWidth?: ResponsiveValue<number | undefined>;
        borderRightWidth?: ResponsiveValue<number | undefined>;
        borderStyle?: ResponsiveValue<"solid" | "dotted" | "dashed" | undefined>;
        borderTopWidth?: ResponsiveValue<number | undefined>;
        borderStartWidth?: ResponsiveValue<number | undefined>;
        borderEndWidth?: ResponsiveValue<number | undefined>;
        borderWidth?: ResponsiveValue<number | undefined>;
    } & {
        borderColor?: ResponsiveValue<PaletteColors> | undefined;
        borderTopColor?: ResponsiveValue<PaletteColors> | undefined;
        borderRightColor?: ResponsiveValue<PaletteColors> | undefined;
        borderLeftColor?: ResponsiveValue<PaletteColors> | undefined;
        borderBottomColor?: ResponsiveValue<PaletteColors> | undefined;
        borderStartColor?: ResponsiveValue<PaletteColors> | undefined;
        borderEndColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        borderRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomRightRadius?: ResponsiveValue<string | number> | undefined;
        borderTopLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderTopRightRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomStartRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomEndRadius?: ResponsiveValue<string | number> | undefined;
        borderTopStartRadius?: ResponsiveValue<string | number> | undefined;
        borderTopEndRadius?: ResponsiveValue<string | number> | undefined;
    } & {
        shadowOpacity?: ResponsiveValue<import("react-native").AnimatableNumericValue | undefined>;
        shadowOffset?: ResponsiveValue<Readonly<{
            width: number;
            height: number;
        }> | undefined>;
        shadowRadius?: ResponsiveValue<number | undefined>;
        elevation?: ResponsiveValue<number | undefined>;
    } & {
        boxShadow?: ResponsiveValue<string | number> | undefined;
        shadowColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        position?: ResponsiveValue<"absolute" | "relative" | undefined>;
        top?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        right?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        bottom?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        left?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        start?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        end?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & {
        zIndex?: ResponsiveValue<string | number> | undefined;
    }) | import("react-native-reanimated").SharedValue<Omit<Partial<{
        end: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        start: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        elevation: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        margin: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginTop: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginRight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginBottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginLeft: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginHorizontal: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginVertical: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginStart: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginEnd: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        padding: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingTop: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingRight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingBottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingLeft: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingHorizontal: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingVertical: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingStart: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingEnd: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        width: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        height: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        minWidth: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        maxWidth: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        minHeight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        maxHeight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        overflow: "scroll" | "visible" | "hidden" | import("moti").SequenceItem<"scroll" | "visible" | "hidden" | undefined>[] | undefined;
        aspectRatio: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
        alignContent: "center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>[] | undefined;
        alignItems: import("react-native").FlexAlignType | import("moti").SequenceItem<import("react-native").FlexAlignType | undefined>[] | undefined;
        alignSelf: "auto" | import("react-native").FlexAlignType | import("moti").SequenceItem<"auto" | import("react-native").FlexAlignType | undefined>[] | undefined;
        justifyContent: "center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>[] | undefined;
        flex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexBasis: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        flexDirection: "row" | "column" | "row-reverse" | "column-reverse" | import("moti").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | undefined;
        flexGrow: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexShrink: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexWrap: "wrap" | "nowrap" | "wrap-reverse" | import("moti").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | undefined;
        transformMatrix: number[] | import("moti").SequenceItem<number[] | undefined>[] | undefined;
        rotation: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        position: "absolute" | "relative" | import("moti").SequenceItem<"absolute" | "relative" | undefined>[] | undefined;
        top: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        right: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        bottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        left: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        borderBottomWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderLeftWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderRightWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderStyle: "solid" | "dotted" | "dashed" | import("moti").SequenceItem<"solid" | "dotted" | "dashed" | undefined>[] | undefined;
        borderTopWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderStartWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderEndWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderTopColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderRightColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderLeftColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBottomColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderStartColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderEndColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomLeftRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomRightRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopLeftRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopRightRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        shadowOpacity: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        shadowOffset: Readonly<{
            width: number;
            height: number;
        }> | import("moti").SequenceItem<Readonly<{
            width: number;
            height: number;
        }> | undefined>[] | undefined;
        shadowRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        display: "none" | "flex" | import("moti").SequenceItem<"none" | "flex" | undefined>[] | undefined;
        backfaceVisibility: "visible" | "hidden" | import("moti").SequenceItem<"visible" | "hidden" | undefined>[] | undefined;
        backgroundColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockEndColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockStartColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderCurve: "circular" | "continuous" | import("moti").SequenceItem<"circular" | "continuous" | undefined>[] | undefined;
        borderEndEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderEndStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderStartEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderStartStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        opacity: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        pointerEvents: "auto" | "none" | "box-none" | "box-only" | import("moti").SequenceItem<"auto" | "none" | "box-none" | "box-only" | undefined>[] | undefined;
        rowGap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        gap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        columnGap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        zIndex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        direction: "inherit" | "ltr" | "rtl" | import("moti").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | undefined;
        shadowColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
    } & {
        scaleX?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        scaleY?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        translateX?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        translateY?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        perspective?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        rotate?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateX?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateY?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateZ?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        scale?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        skewX?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        skewY?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
    } & import("moti").StyleValueWithSequenceArraysWithTransform>, keyof import("react-native").ViewStyle> & Omit<import("react-native").ViewStyle, "p" | "ms" | "end" | "start" | "m" | "py" | "pl" | "elevation" | "margin" | "marginTop" | "marginRight" | "marginBottom" | "marginLeft" | "marginHorizontal" | "marginVertical" | "marginStart" | "marginEnd" | "padding" | "paddingTop" | "paddingRight" | "paddingBottom" | "paddingLeft" | "paddingHorizontal" | "paddingVertical" | "paddingStart" | "paddingEnd" | "width" | "height" | "minWidth" | "maxWidth" | "minHeight" | "maxHeight" | "mt" | "mr" | "mb" | "ml" | "mx" | "my" | "me" | "pt" | "pr" | "pb" | "px" | "ps" | "pe" | "overflow" | "aspectRatio" | "alignContent" | "alignItems" | "alignSelf" | "justifyContent" | "flex" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "w" | "h" | "minW" | "maxW" | "minH" | "maxH" | "transform" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "position" | "top" | "right" | "bottom" | "left" | "borderBottomWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStyle" | "borderTopWidth" | "borderStartWidth" | "borderEndWidth" | "borderWidth" | "borderColor" | "borderTopColor" | "borderRightColor" | "borderLeftColor" | "borderBottomColor" | "borderStartColor" | "borderEndColor" | "borderRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderBottomStartRadius" | "borderBottomEndRadius" | "borderTopStartRadius" | "borderTopEndRadius" | "shadowOpacity" | "shadowOffset" | "shadowRadius" | "opacity" | "zIndex" | "shadowColor" | keyof import("../../../theme").BackgroundColorProps | "visible" | "boxShadow"> & import("../../../theme").BackgroundColorProps & import("../../../theme").OpacityProps & import("../../../theme").VisibleProps & {
        width?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        height?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        overflow?: ResponsiveValue<"scroll" | "visible" | "hidden" | undefined>;
        aspectRatio?: ResponsiveValue<string | number | undefined>;
        alignContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>;
        alignItems?: ResponsiveValue<import("react-native").FlexAlignType | undefined>;
        alignSelf?: ResponsiveValue<"auto" | import("react-native").FlexAlignType | undefined>;
        justifyContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>;
        flex?: ResponsiveValue<number | undefined>;
        flexBasis?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        flexDirection?: ResponsiveValue<"row" | "column" | "row-reverse" | "column-reverse" | undefined>;
        flexGrow?: ResponsiveValue<number | undefined>;
        flexShrink?: ResponsiveValue<number | undefined>;
        flexWrap?: ResponsiveValue<"wrap" | "nowrap" | "wrap-reverse" | undefined>;
    } & {
        readonly w?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly h?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & import("../../../theme").TransformProps & {
        margin?: ResponsiveValue<string | number> | undefined;
        marginTop?: ResponsiveValue<string | number> | undefined;
        marginRight?: ResponsiveValue<string | number> | undefined;
        marginBottom?: ResponsiveValue<string | number> | undefined;
        marginLeft?: ResponsiveValue<string | number> | undefined;
        marginHorizontal?: ResponsiveValue<string | number> | undefined;
        marginVertical?: ResponsiveValue<string | number> | undefined;
        marginStart?: ResponsiveValue<string | number> | undefined;
        marginEnd?: ResponsiveValue<string | number> | undefined;
        padding?: ResponsiveValue<string | number> | undefined;
        paddingTop?: ResponsiveValue<string | number> | undefined;
        paddingRight?: ResponsiveValue<string | number> | undefined;
        paddingBottom?: ResponsiveValue<string | number> | undefined;
        paddingLeft?: ResponsiveValue<string | number> | undefined;
        paddingHorizontal?: ResponsiveValue<string | number> | undefined;
        paddingVertical?: ResponsiveValue<string | number> | undefined;
        paddingStart?: ResponsiveValue<string | number> | undefined;
        paddingEnd?: ResponsiveValue<string | number> | undefined;
    } & {
        readonly m?: ResponsiveValue<string | number> | undefined;
        readonly mt?: ResponsiveValue<string | number> | undefined;
        readonly mr?: ResponsiveValue<string | number> | undefined;
        readonly mb?: ResponsiveValue<string | number> | undefined;
        readonly ml?: ResponsiveValue<string | number> | undefined;
        readonly mx?: ResponsiveValue<string | number> | undefined;
        readonly my?: ResponsiveValue<string | number> | undefined;
        readonly ms?: ResponsiveValue<string | number> | undefined;
        readonly me?: ResponsiveValue<string | number> | undefined;
        readonly p?: ResponsiveValue<string | number> | undefined;
        readonly pt?: ResponsiveValue<string | number> | undefined;
        readonly pr?: ResponsiveValue<string | number> | undefined;
        readonly pb?: ResponsiveValue<string | number> | undefined;
        readonly pl?: ResponsiveValue<string | number> | undefined;
        readonly px?: ResponsiveValue<string | number> | undefined;
        readonly py?: ResponsiveValue<string | number> | undefined;
        readonly ps?: ResponsiveValue<string | number> | undefined;
        readonly pe?: ResponsiveValue<string | number> | undefined;
    } & {
        borderBottomWidth?: ResponsiveValue<number | undefined>;
        borderLeftWidth?: ResponsiveValue<number | undefined>;
        borderRightWidth?: ResponsiveValue<number | undefined>;
        borderStyle?: ResponsiveValue<"solid" | "dotted" | "dashed" | undefined>;
        borderTopWidth?: ResponsiveValue<number | undefined>;
        borderStartWidth?: ResponsiveValue<number | undefined>;
        borderEndWidth?: ResponsiveValue<number | undefined>;
        borderWidth?: ResponsiveValue<number | undefined>;
    } & {
        borderColor?: ResponsiveValue<PaletteColors> | undefined;
        borderTopColor?: ResponsiveValue<PaletteColors> | undefined;
        borderRightColor?: ResponsiveValue<PaletteColors> | undefined;
        borderLeftColor?: ResponsiveValue<PaletteColors> | undefined;
        borderBottomColor?: ResponsiveValue<PaletteColors> | undefined;
        borderStartColor?: ResponsiveValue<PaletteColors> | undefined;
        borderEndColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        borderRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomRightRadius?: ResponsiveValue<string | number> | undefined;
        borderTopLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderTopRightRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomStartRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomEndRadius?: ResponsiveValue<string | number> | undefined;
        borderTopStartRadius?: ResponsiveValue<string | number> | undefined;
        borderTopEndRadius?: ResponsiveValue<string | number> | undefined;
    } & {
        shadowOpacity?: ResponsiveValue<import("react-native").AnimatableNumericValue | undefined>;
        shadowOffset?: ResponsiveValue<Readonly<{
            width: number;
            height: number;
        }> | undefined>;
        shadowRadius?: ResponsiveValue<number | undefined>;
        elevation?: ResponsiveValue<number | undefined>;
    } & {
        boxShadow?: ResponsiveValue<string | number> | undefined;
        shadowColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        position?: ResponsiveValue<"absolute" | "relative" | undefined>;
        top?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        right?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        bottom?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        left?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        start?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        end?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & {
        zIndex?: ResponsiveValue<string | number> | undefined;
    }>) | undefined;
    exit?: boolean | (Omit<import("moti").StyleValueWithReplacedTransforms<import("react-native").ViewStyle>, keyof import("react-native").ViewStyle> & Omit<import("react-native").ViewStyle, "p" | "ms" | "end" | "start" | "m" | "py" | "pl" | "elevation" | "margin" | "marginTop" | "marginRight" | "marginBottom" | "marginLeft" | "marginHorizontal" | "marginVertical" | "marginStart" | "marginEnd" | "padding" | "paddingTop" | "paddingRight" | "paddingBottom" | "paddingLeft" | "paddingHorizontal" | "paddingVertical" | "paddingStart" | "paddingEnd" | "width" | "height" | "minWidth" | "maxWidth" | "minHeight" | "maxHeight" | "mt" | "mr" | "mb" | "ml" | "mx" | "my" | "me" | "pt" | "pr" | "pb" | "px" | "ps" | "pe" | "overflow" | "aspectRatio" | "alignContent" | "alignItems" | "alignSelf" | "justifyContent" | "flex" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "w" | "h" | "minW" | "maxW" | "minH" | "maxH" | "transform" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "position" | "top" | "right" | "bottom" | "left" | "borderBottomWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStyle" | "borderTopWidth" | "borderStartWidth" | "borderEndWidth" | "borderWidth" | "borderColor" | "borderTopColor" | "borderRightColor" | "borderLeftColor" | "borderBottomColor" | "borderStartColor" | "borderEndColor" | "borderRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderBottomStartRadius" | "borderBottomEndRadius" | "borderTopStartRadius" | "borderTopEndRadius" | "shadowOpacity" | "shadowOffset" | "shadowRadius" | "opacity" | "zIndex" | "shadowColor" | keyof import("../../../theme").BackgroundColorProps | "visible" | "boxShadow"> & import("../../../theme").BackgroundColorProps & import("../../../theme").OpacityProps & import("../../../theme").VisibleProps & {
        width?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        height?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        overflow?: ResponsiveValue<"scroll" | "visible" | "hidden" | undefined>;
        aspectRatio?: ResponsiveValue<string | number | undefined>;
        alignContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>;
        alignItems?: ResponsiveValue<import("react-native").FlexAlignType | undefined>;
        alignSelf?: ResponsiveValue<"auto" | import("react-native").FlexAlignType | undefined>;
        justifyContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>;
        flex?: ResponsiveValue<number | undefined>;
        flexBasis?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        flexDirection?: ResponsiveValue<"row" | "column" | "row-reverse" | "column-reverse" | undefined>;
        flexGrow?: ResponsiveValue<number | undefined>;
        flexShrink?: ResponsiveValue<number | undefined>;
        flexWrap?: ResponsiveValue<"wrap" | "nowrap" | "wrap-reverse" | undefined>;
    } & {
        readonly w?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly h?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & import("../../../theme").TransformProps & {
        margin?: ResponsiveValue<string | number> | undefined;
        marginTop?: ResponsiveValue<string | number> | undefined;
        marginRight?: ResponsiveValue<string | number> | undefined;
        marginBottom?: ResponsiveValue<string | number> | undefined;
        marginLeft?: ResponsiveValue<string | number> | undefined;
        marginHorizontal?: ResponsiveValue<string | number> | undefined;
        marginVertical?: ResponsiveValue<string | number> | undefined;
        marginStart?: ResponsiveValue<string | number> | undefined;
        marginEnd?: ResponsiveValue<string | number> | undefined;
        padding?: ResponsiveValue<string | number> | undefined;
        paddingTop?: ResponsiveValue<string | number> | undefined;
        paddingRight?: ResponsiveValue<string | number> | undefined;
        paddingBottom?: ResponsiveValue<string | number> | undefined;
        paddingLeft?: ResponsiveValue<string | number> | undefined;
        paddingHorizontal?: ResponsiveValue<string | number> | undefined;
        paddingVertical?: ResponsiveValue<string | number> | undefined;
        paddingStart?: ResponsiveValue<string | number> | undefined;
        paddingEnd?: ResponsiveValue<string | number> | undefined;
    } & {
        readonly m?: ResponsiveValue<string | number> | undefined;
        readonly mt?: ResponsiveValue<string | number> | undefined;
        readonly mr?: ResponsiveValue<string | number> | undefined;
        readonly mb?: ResponsiveValue<string | number> | undefined;
        readonly ml?: ResponsiveValue<string | number> | undefined;
        readonly mx?: ResponsiveValue<string | number> | undefined;
        readonly my?: ResponsiveValue<string | number> | undefined;
        readonly ms?: ResponsiveValue<string | number> | undefined;
        readonly me?: ResponsiveValue<string | number> | undefined;
        readonly p?: ResponsiveValue<string | number> | undefined;
        readonly pt?: ResponsiveValue<string | number> | undefined;
        readonly pr?: ResponsiveValue<string | number> | undefined;
        readonly pb?: ResponsiveValue<string | number> | undefined;
        readonly pl?: ResponsiveValue<string | number> | undefined;
        readonly px?: ResponsiveValue<string | number> | undefined;
        readonly py?: ResponsiveValue<string | number> | undefined;
        readonly ps?: ResponsiveValue<string | number> | undefined;
        readonly pe?: ResponsiveValue<string | number> | undefined;
    } & {
        borderBottomWidth?: ResponsiveValue<number | undefined>;
        borderLeftWidth?: ResponsiveValue<number | undefined>;
        borderRightWidth?: ResponsiveValue<number | undefined>;
        borderStyle?: ResponsiveValue<"solid" | "dotted" | "dashed" | undefined>;
        borderTopWidth?: ResponsiveValue<number | undefined>;
        borderStartWidth?: ResponsiveValue<number | undefined>;
        borderEndWidth?: ResponsiveValue<number | undefined>;
        borderWidth?: ResponsiveValue<number | undefined>;
    } & {
        borderColor?: ResponsiveValue<PaletteColors> | undefined;
        borderTopColor?: ResponsiveValue<PaletteColors> | undefined;
        borderRightColor?: ResponsiveValue<PaletteColors> | undefined;
        borderLeftColor?: ResponsiveValue<PaletteColors> | undefined;
        borderBottomColor?: ResponsiveValue<PaletteColors> | undefined;
        borderStartColor?: ResponsiveValue<PaletteColors> | undefined;
        borderEndColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        borderRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomRightRadius?: ResponsiveValue<string | number> | undefined;
        borderTopLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderTopRightRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomStartRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomEndRadius?: ResponsiveValue<string | number> | undefined;
        borderTopStartRadius?: ResponsiveValue<string | number> | undefined;
        borderTopEndRadius?: ResponsiveValue<string | number> | undefined;
    } & {
        shadowOpacity?: ResponsiveValue<import("react-native").AnimatableNumericValue | undefined>;
        shadowOffset?: ResponsiveValue<Readonly<{
            width: number;
            height: number;
        }> | undefined>;
        shadowRadius?: ResponsiveValue<number | undefined>;
        elevation?: ResponsiveValue<number | undefined>;
    } & {
        boxShadow?: ResponsiveValue<string | number> | undefined;
        shadowColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        position?: ResponsiveValue<"absolute" | "relative" | undefined>;
        top?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        right?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        bottom?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        left?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        start?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        end?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & {
        zIndex?: ResponsiveValue<string | number> | undefined;
    }) | ((custom?: any) => Omit<import("moti").StyleValueWithReplacedTransforms<import("react-native").ViewStyle>, keyof import("react-native").ViewStyle> & Omit<import("react-native").ViewStyle, "p" | "ms" | "end" | "start" | "m" | "py" | "pl" | "elevation" | "margin" | "marginTop" | "marginRight" | "marginBottom" | "marginLeft" | "marginHorizontal" | "marginVertical" | "marginStart" | "marginEnd" | "padding" | "paddingTop" | "paddingRight" | "paddingBottom" | "paddingLeft" | "paddingHorizontal" | "paddingVertical" | "paddingStart" | "paddingEnd" | "width" | "height" | "minWidth" | "maxWidth" | "minHeight" | "maxHeight" | "mt" | "mr" | "mb" | "ml" | "mx" | "my" | "me" | "pt" | "pr" | "pb" | "px" | "ps" | "pe" | "overflow" | "aspectRatio" | "alignContent" | "alignItems" | "alignSelf" | "justifyContent" | "flex" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "w" | "h" | "minW" | "maxW" | "minH" | "maxH" | "transform" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "position" | "top" | "right" | "bottom" | "left" | "borderBottomWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStyle" | "borderTopWidth" | "borderStartWidth" | "borderEndWidth" | "borderWidth" | "borderColor" | "borderTopColor" | "borderRightColor" | "borderLeftColor" | "borderBottomColor" | "borderStartColor" | "borderEndColor" | "borderRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderBottomStartRadius" | "borderBottomEndRadius" | "borderTopStartRadius" | "borderTopEndRadius" | "shadowOpacity" | "shadowOffset" | "shadowRadius" | "opacity" | "zIndex" | "shadowColor" | keyof import("../../../theme").BackgroundColorProps | "visible" | "boxShadow"> & import("../../../theme").BackgroundColorProps & import("../../../theme").OpacityProps & import("../../../theme").VisibleProps & {
        width?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        height?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        overflow?: ResponsiveValue<"scroll" | "visible" | "hidden" | undefined>;
        aspectRatio?: ResponsiveValue<string | number | undefined>;
        alignContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>;
        alignItems?: ResponsiveValue<import("react-native").FlexAlignType | undefined>;
        alignSelf?: ResponsiveValue<"auto" | import("react-native").FlexAlignType | undefined>;
        justifyContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>;
        flex?: ResponsiveValue<number | undefined>;
        flexBasis?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        flexDirection?: ResponsiveValue<"row" | "column" | "row-reverse" | "column-reverse" | undefined>;
        flexGrow?: ResponsiveValue<number | undefined>;
        flexShrink?: ResponsiveValue<number | undefined>;
        flexWrap?: ResponsiveValue<"wrap" | "nowrap" | "wrap-reverse" | undefined>;
    } & {
        readonly w?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly h?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & import("../../../theme").TransformProps & {
        margin?: ResponsiveValue<string | number> | undefined;
        marginTop?: ResponsiveValue<string | number> | undefined;
        marginRight?: ResponsiveValue<string | number> | undefined;
        marginBottom?: ResponsiveValue<string | number> | undefined;
        marginLeft?: ResponsiveValue<string | number> | undefined;
        marginHorizontal?: ResponsiveValue<string | number> | undefined;
        marginVertical?: ResponsiveValue<string | number> | undefined;
        marginStart?: ResponsiveValue<string | number> | undefined;
        marginEnd?: ResponsiveValue<string | number> | undefined;
        padding?: ResponsiveValue<string | number> | undefined;
        paddingTop?: ResponsiveValue<string | number> | undefined;
        paddingRight?: ResponsiveValue<string | number> | undefined;
        paddingBottom?: ResponsiveValue<string | number> | undefined;
        paddingLeft?: ResponsiveValue<string | number> | undefined;
        paddingHorizontal?: ResponsiveValue<string | number> | undefined;
        paddingVertical?: ResponsiveValue<string | number> | undefined;
        paddingStart?: ResponsiveValue<string | number> | undefined;
        paddingEnd?: ResponsiveValue<string | number> | undefined;
    } & {
        readonly m?: ResponsiveValue<string | number> | undefined;
        readonly mt?: ResponsiveValue<string | number> | undefined;
        readonly mr?: ResponsiveValue<string | number> | undefined;
        readonly mb?: ResponsiveValue<string | number> | undefined;
        readonly ml?: ResponsiveValue<string | number> | undefined;
        readonly mx?: ResponsiveValue<string | number> | undefined;
        readonly my?: ResponsiveValue<string | number> | undefined;
        readonly ms?: ResponsiveValue<string | number> | undefined;
        readonly me?: ResponsiveValue<string | number> | undefined;
        readonly p?: ResponsiveValue<string | number> | undefined;
        readonly pt?: ResponsiveValue<string | number> | undefined;
        readonly pr?: ResponsiveValue<string | number> | undefined;
        readonly pb?: ResponsiveValue<string | number> | undefined;
        readonly pl?: ResponsiveValue<string | number> | undefined;
        readonly px?: ResponsiveValue<string | number> | undefined;
        readonly py?: ResponsiveValue<string | number> | undefined;
        readonly ps?: ResponsiveValue<string | number> | undefined;
        readonly pe?: ResponsiveValue<string | number> | undefined;
    } & {
        borderBottomWidth?: ResponsiveValue<number | undefined>;
        borderLeftWidth?: ResponsiveValue<number | undefined>;
        borderRightWidth?: ResponsiveValue<number | undefined>;
        borderStyle?: ResponsiveValue<"solid" | "dotted" | "dashed" | undefined>;
        borderTopWidth?: ResponsiveValue<number | undefined>;
        borderStartWidth?: ResponsiveValue<number | undefined>;
        borderEndWidth?: ResponsiveValue<number | undefined>;
        borderWidth?: ResponsiveValue<number | undefined>;
    } & {
        borderColor?: ResponsiveValue<PaletteColors> | undefined;
        borderTopColor?: ResponsiveValue<PaletteColors> | undefined;
        borderRightColor?: ResponsiveValue<PaletteColors> | undefined;
        borderLeftColor?: ResponsiveValue<PaletteColors> | undefined;
        borderBottomColor?: ResponsiveValue<PaletteColors> | undefined;
        borderStartColor?: ResponsiveValue<PaletteColors> | undefined;
        borderEndColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        borderRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomRightRadius?: ResponsiveValue<string | number> | undefined;
        borderTopLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderTopRightRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomStartRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomEndRadius?: ResponsiveValue<string | number> | undefined;
        borderTopStartRadius?: ResponsiveValue<string | number> | undefined;
        borderTopEndRadius?: ResponsiveValue<string | number> | undefined;
    } & {
        shadowOpacity?: ResponsiveValue<import("react-native").AnimatableNumericValue | undefined>;
        shadowOffset?: ResponsiveValue<Readonly<{
            width: number;
            height: number;
        }> | undefined>;
        shadowRadius?: ResponsiveValue<number | undefined>;
        elevation?: ResponsiveValue<number | undefined>;
    } & {
        boxShadow?: ResponsiveValue<string | number> | undefined;
        shadowColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        position?: ResponsiveValue<"absolute" | "relative" | undefined>;
        top?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        right?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        bottom?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        left?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        start?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        end?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & {
        zIndex?: ResponsiveValue<string | number> | undefined;
    }) | undefined;
    transition?: import("moti").MotiTransitionProp<Omit<import("moti").StyleValueWithReplacedTransforms<import("react-native").ViewStyle>, keyof import("react-native").ViewStyle> & Omit<import("react-native").ViewStyle, "p" | "ms" | "end" | "start" | "m" | "py" | "pl" | "elevation" | "margin" | "marginTop" | "marginRight" | "marginBottom" | "marginLeft" | "marginHorizontal" | "marginVertical" | "marginStart" | "marginEnd" | "padding" | "paddingTop" | "paddingRight" | "paddingBottom" | "paddingLeft" | "paddingHorizontal" | "paddingVertical" | "paddingStart" | "paddingEnd" | "width" | "height" | "minWidth" | "maxWidth" | "minHeight" | "maxHeight" | "mt" | "mr" | "mb" | "ml" | "mx" | "my" | "me" | "pt" | "pr" | "pb" | "px" | "ps" | "pe" | "overflow" | "aspectRatio" | "alignContent" | "alignItems" | "alignSelf" | "justifyContent" | "flex" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "w" | "h" | "minW" | "maxW" | "minH" | "maxH" | "transform" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "position" | "top" | "right" | "bottom" | "left" | "borderBottomWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStyle" | "borderTopWidth" | "borderStartWidth" | "borderEndWidth" | "borderWidth" | "borderColor" | "borderTopColor" | "borderRightColor" | "borderLeftColor" | "borderBottomColor" | "borderStartColor" | "borderEndColor" | "borderRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderBottomStartRadius" | "borderBottomEndRadius" | "borderTopStartRadius" | "borderTopEndRadius" | "shadowOpacity" | "shadowOffset" | "shadowRadius" | "opacity" | "zIndex" | "shadowColor" | keyof import("../../../theme").BackgroundColorProps | "visible" | "boxShadow"> & import("../../../theme").BackgroundColorProps & import("../../../theme").OpacityProps & import("../../../theme").VisibleProps & {
        width?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        height?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        overflow?: ResponsiveValue<"scroll" | "visible" | "hidden" | undefined>;
        aspectRatio?: ResponsiveValue<string | number | undefined>;
        alignContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>;
        alignItems?: ResponsiveValue<import("react-native").FlexAlignType | undefined>;
        alignSelf?: ResponsiveValue<"auto" | import("react-native").FlexAlignType | undefined>;
        justifyContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>;
        flex?: ResponsiveValue<number | undefined>;
        flexBasis?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        flexDirection?: ResponsiveValue<"row" | "column" | "row-reverse" | "column-reverse" | undefined>;
        flexGrow?: ResponsiveValue<number | undefined>;
        flexShrink?: ResponsiveValue<number | undefined>;
        flexWrap?: ResponsiveValue<"wrap" | "nowrap" | "wrap-reverse" | undefined>;
    } & {
        readonly w?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly h?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & import("../../../theme").TransformProps & {
        margin?: ResponsiveValue<string | number> | undefined;
        marginTop?: ResponsiveValue<string | number> | undefined;
        marginRight?: ResponsiveValue<string | number> | undefined;
        marginBottom?: ResponsiveValue<string | number> | undefined;
        marginLeft?: ResponsiveValue<string | number> | undefined;
        marginHorizontal?: ResponsiveValue<string | number> | undefined;
        marginVertical?: ResponsiveValue<string | number> | undefined;
        marginStart?: ResponsiveValue<string | number> | undefined;
        marginEnd?: ResponsiveValue<string | number> | undefined;
        padding?: ResponsiveValue<string | number> | undefined;
        paddingTop?: ResponsiveValue<string | number> | undefined;
        paddingRight?: ResponsiveValue<string | number> | undefined;
        paddingBottom?: ResponsiveValue<string | number> | undefined;
        paddingLeft?: ResponsiveValue<string | number> | undefined;
        paddingHorizontal?: ResponsiveValue<string | number> | undefined;
        paddingVertical?: ResponsiveValue<string | number> | undefined;
        paddingStart?: ResponsiveValue<string | number> | undefined;
        paddingEnd?: ResponsiveValue<string | number> | undefined;
    } & {
        readonly m?: ResponsiveValue<string | number> | undefined;
        readonly mt?: ResponsiveValue<string | number> | undefined;
        readonly mr?: ResponsiveValue<string | number> | undefined;
        readonly mb?: ResponsiveValue<string | number> | undefined;
        readonly ml?: ResponsiveValue<string | number> | undefined;
        readonly mx?: ResponsiveValue<string | number> | undefined;
        readonly my?: ResponsiveValue<string | number> | undefined;
        readonly ms?: ResponsiveValue<string | number> | undefined;
        readonly me?: ResponsiveValue<string | number> | undefined;
        readonly p?: ResponsiveValue<string | number> | undefined;
        readonly pt?: ResponsiveValue<string | number> | undefined;
        readonly pr?: ResponsiveValue<string | number> | undefined;
        readonly pb?: ResponsiveValue<string | number> | undefined;
        readonly pl?: ResponsiveValue<string | number> | undefined;
        readonly px?: ResponsiveValue<string | number> | undefined;
        readonly py?: ResponsiveValue<string | number> | undefined;
        readonly ps?: ResponsiveValue<string | number> | undefined;
        readonly pe?: ResponsiveValue<string | number> | undefined;
    } & {
        borderBottomWidth?: ResponsiveValue<number | undefined>;
        borderLeftWidth?: ResponsiveValue<number | undefined>;
        borderRightWidth?: ResponsiveValue<number | undefined>;
        borderStyle?: ResponsiveValue<"solid" | "dotted" | "dashed" | undefined>;
        borderTopWidth?: ResponsiveValue<number | undefined>;
        borderStartWidth?: ResponsiveValue<number | undefined>;
        borderEndWidth?: ResponsiveValue<number | undefined>;
        borderWidth?: ResponsiveValue<number | undefined>;
    } & {
        borderColor?: ResponsiveValue<PaletteColors> | undefined;
        borderTopColor?: ResponsiveValue<PaletteColors> | undefined;
        borderRightColor?: ResponsiveValue<PaletteColors> | undefined;
        borderLeftColor?: ResponsiveValue<PaletteColors> | undefined;
        borderBottomColor?: ResponsiveValue<PaletteColors> | undefined;
        borderStartColor?: ResponsiveValue<PaletteColors> | undefined;
        borderEndColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        borderRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomRightRadius?: ResponsiveValue<string | number> | undefined;
        borderTopLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderTopRightRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomStartRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomEndRadius?: ResponsiveValue<string | number> | undefined;
        borderTopStartRadius?: ResponsiveValue<string | number> | undefined;
        borderTopEndRadius?: ResponsiveValue<string | number> | undefined;
    } & {
        shadowOpacity?: ResponsiveValue<import("react-native").AnimatableNumericValue | undefined>;
        shadowOffset?: ResponsiveValue<Readonly<{
            width: number;
            height: number;
        }> | undefined>;
        shadowRadius?: ResponsiveValue<number | undefined>;
        elevation?: ResponsiveValue<number | undefined>;
    } & {
        boxShadow?: ResponsiveValue<string | number> | undefined;
        shadowColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        position?: ResponsiveValue<"absolute" | "relative" | undefined>;
        top?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        right?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        bottom?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        left?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        start?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        end?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & {
        zIndex?: ResponsiveValue<string | number> | undefined;
    }> | undefined;
    exitTransition?: import("moti").MotiTransitionProp<Omit<import("moti").StyleValueWithReplacedTransforms<import("react-native").ViewStyle>, keyof import("react-native").ViewStyle> & Omit<import("react-native").ViewStyle, "p" | "ms" | "end" | "start" | "m" | "py" | "pl" | "elevation" | "margin" | "marginTop" | "marginRight" | "marginBottom" | "marginLeft" | "marginHorizontal" | "marginVertical" | "marginStart" | "marginEnd" | "padding" | "paddingTop" | "paddingRight" | "paddingBottom" | "paddingLeft" | "paddingHorizontal" | "paddingVertical" | "paddingStart" | "paddingEnd" | "width" | "height" | "minWidth" | "maxWidth" | "minHeight" | "maxHeight" | "mt" | "mr" | "mb" | "ml" | "mx" | "my" | "me" | "pt" | "pr" | "pb" | "px" | "ps" | "pe" | "overflow" | "aspectRatio" | "alignContent" | "alignItems" | "alignSelf" | "justifyContent" | "flex" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "w" | "h" | "minW" | "maxW" | "minH" | "maxH" | "transform" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "position" | "top" | "right" | "bottom" | "left" | "borderBottomWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStyle" | "borderTopWidth" | "borderStartWidth" | "borderEndWidth" | "borderWidth" | "borderColor" | "borderTopColor" | "borderRightColor" | "borderLeftColor" | "borderBottomColor" | "borderStartColor" | "borderEndColor" | "borderRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderBottomStartRadius" | "borderBottomEndRadius" | "borderTopStartRadius" | "borderTopEndRadius" | "shadowOpacity" | "shadowOffset" | "shadowRadius" | "opacity" | "zIndex" | "shadowColor" | keyof import("../../../theme").BackgroundColorProps | "visible" | "boxShadow"> & import("../../../theme").BackgroundColorProps & import("../../../theme").OpacityProps & import("../../../theme").VisibleProps & {
        width?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        height?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        overflow?: ResponsiveValue<"scroll" | "visible" | "hidden" | undefined>;
        aspectRatio?: ResponsiveValue<string | number | undefined>;
        alignContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>;
        alignItems?: ResponsiveValue<import("react-native").FlexAlignType | undefined>;
        alignSelf?: ResponsiveValue<"auto" | import("react-native").FlexAlignType | undefined>;
        justifyContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>;
        flex?: ResponsiveValue<number | undefined>;
        flexBasis?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        flexDirection?: ResponsiveValue<"row" | "column" | "row-reverse" | "column-reverse" | undefined>;
        flexGrow?: ResponsiveValue<number | undefined>;
        flexShrink?: ResponsiveValue<number | undefined>;
        flexWrap?: ResponsiveValue<"wrap" | "nowrap" | "wrap-reverse" | undefined>;
    } & {
        readonly w?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly h?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & import("../../../theme").TransformProps & {
        margin?: ResponsiveValue<string | number> | undefined;
        marginTop?: ResponsiveValue<string | number> | undefined;
        marginRight?: ResponsiveValue<string | number> | undefined;
        marginBottom?: ResponsiveValue<string | number> | undefined;
        marginLeft?: ResponsiveValue<string | number> | undefined;
        marginHorizontal?: ResponsiveValue<string | number> | undefined;
        marginVertical?: ResponsiveValue<string | number> | undefined;
        marginStart?: ResponsiveValue<string | number> | undefined;
        marginEnd?: ResponsiveValue<string | number> | undefined;
        padding?: ResponsiveValue<string | number> | undefined;
        paddingTop?: ResponsiveValue<string | number> | undefined;
        paddingRight?: ResponsiveValue<string | number> | undefined;
        paddingBottom?: ResponsiveValue<string | number> | undefined;
        paddingLeft?: ResponsiveValue<string | number> | undefined;
        paddingHorizontal?: ResponsiveValue<string | number> | undefined;
        paddingVertical?: ResponsiveValue<string | number> | undefined;
        paddingStart?: ResponsiveValue<string | number> | undefined;
        paddingEnd?: ResponsiveValue<string | number> | undefined;
    } & {
        readonly m?: ResponsiveValue<string | number> | undefined;
        readonly mt?: ResponsiveValue<string | number> | undefined;
        readonly mr?: ResponsiveValue<string | number> | undefined;
        readonly mb?: ResponsiveValue<string | number> | undefined;
        readonly ml?: ResponsiveValue<string | number> | undefined;
        readonly mx?: ResponsiveValue<string | number> | undefined;
        readonly my?: ResponsiveValue<string | number> | undefined;
        readonly ms?: ResponsiveValue<string | number> | undefined;
        readonly me?: ResponsiveValue<string | number> | undefined;
        readonly p?: ResponsiveValue<string | number> | undefined;
        readonly pt?: ResponsiveValue<string | number> | undefined;
        readonly pr?: ResponsiveValue<string | number> | undefined;
        readonly pb?: ResponsiveValue<string | number> | undefined;
        readonly pl?: ResponsiveValue<string | number> | undefined;
        readonly px?: ResponsiveValue<string | number> | undefined;
        readonly py?: ResponsiveValue<string | number> | undefined;
        readonly ps?: ResponsiveValue<string | number> | undefined;
        readonly pe?: ResponsiveValue<string | number> | undefined;
    } & {
        borderBottomWidth?: ResponsiveValue<number | undefined>;
        borderLeftWidth?: ResponsiveValue<number | undefined>;
        borderRightWidth?: ResponsiveValue<number | undefined>;
        borderStyle?: ResponsiveValue<"solid" | "dotted" | "dashed" | undefined>;
        borderTopWidth?: ResponsiveValue<number | undefined>;
        borderStartWidth?: ResponsiveValue<number | undefined>;
        borderEndWidth?: ResponsiveValue<number | undefined>;
        borderWidth?: ResponsiveValue<number | undefined>;
    } & {
        borderColor?: ResponsiveValue<PaletteColors> | undefined;
        borderTopColor?: ResponsiveValue<PaletteColors> | undefined;
        borderRightColor?: ResponsiveValue<PaletteColors> | undefined;
        borderLeftColor?: ResponsiveValue<PaletteColors> | undefined;
        borderBottomColor?: ResponsiveValue<PaletteColors> | undefined;
        borderStartColor?: ResponsiveValue<PaletteColors> | undefined;
        borderEndColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        borderRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomRightRadius?: ResponsiveValue<string | number> | undefined;
        borderTopLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderTopRightRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomStartRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomEndRadius?: ResponsiveValue<string | number> | undefined;
        borderTopStartRadius?: ResponsiveValue<string | number> | undefined;
        borderTopEndRadius?: ResponsiveValue<string | number> | undefined;
    } & {
        shadowOpacity?: ResponsiveValue<import("react-native").AnimatableNumericValue | undefined>;
        shadowOffset?: ResponsiveValue<Readonly<{
            width: number;
            height: number;
        }> | undefined>;
        shadowRadius?: ResponsiveValue<number | undefined>;
        elevation?: ResponsiveValue<number | undefined>;
    } & {
        boxShadow?: ResponsiveValue<string | number> | undefined;
        shadowColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        position?: ResponsiveValue<"absolute" | "relative" | undefined>;
        top?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        right?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        bottom?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        left?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        start?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        end?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & {
        zIndex?: ResponsiveValue<string | number> | undefined;
    }> | undefined;
    state?: Pick<import("moti").UseAnimationState<any>, "__state"> | undefined;
} & Omit<BaseSkeletonProps, ("p" | "ms" | "end" | "start" | "m" | "py" | "pl" | "elevation" | "margin" | "marginTop" | "marginRight" | "marginBottom" | "marginLeft" | "marginHorizontal" | "marginVertical" | "marginStart" | "marginEnd" | "padding" | "paddingTop" | "paddingRight" | "paddingBottom" | "paddingLeft" | "paddingHorizontal" | "paddingVertical" | "paddingStart" | "paddingEnd" | "width" | "height" | "minWidth" | "maxWidth" | "minHeight" | "maxHeight" | "mt" | "mr" | "mb" | "ml" | "mx" | "my" | "me" | "pt" | "pr" | "pb" | "px" | "ps" | "pe" | "overflow" | "aspectRatio" | "alignContent" | "alignItems" | "alignSelf" | "justifyContent" | "flex" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "w" | "h" | "minW" | "maxW" | "minH" | "maxH" | "transform" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "position" | "top" | "right" | "bottom" | "left" | "borderBottomWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStyle" | "borderTopWidth" | "borderStartWidth" | "borderEndWidth" | "borderWidth" | "borderColor" | "borderTopColor" | "borderRightColor" | "borderLeftColor" | "borderBottomColor" | "borderStartColor" | "borderEndColor" | "borderRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderBottomStartRadius" | "borderBottomEndRadius" | "borderTopStartRadius" | "borderTopEndRadius" | "shadowOpacity" | "shadowOffset" | "shadowRadius" | "opacity" | "zIndex" | "shadowColor" | keyof import("../../../theme").BackgroundColorProps | "visible" | "boxShadow") & Pick<import("react-native").ViewProps & {
    animatedProps?: Partial<import("react-native").ViewProps> | undefined;
    layout?: import("react-native-reanimated").BaseAnimationBuilder | import("react-native-reanimated").LayoutAnimationFunction | typeof import("react-native-reanimated").BaseAnimationBuilder | undefined;
    entering?: import("react-native-reanimated").BaseAnimationBuilder | typeof import("react-native-reanimated").BaseAnimationBuilder | import("react-native-reanimated").EntryExitAnimationFunction | Keyframe | undefined;
    exiting?: import("react-native-reanimated").BaseAnimationBuilder | typeof import("react-native-reanimated").BaseAnimationBuilder | import("react-native-reanimated").EntryExitAnimationFunction | Keyframe | undefined;
} & import("moti").MotiProps<import("react-native").ViewStyle | import("react-native").ImageStyle | import("react-native").TextStyle, import("moti").StyleValueWithReplacedTransforms<import("react-native").ViewStyle | import("react-native").ImageStyle | import("react-native").TextStyle>, Partial<{
    backfaceVisibility: "visible" | "hidden" | import("moti").SequenceItem<"visible" | "hidden" | undefined>[] | undefined;
    backgroundColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
    borderBottomLeftRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderBottomRightRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderBottomWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
    borderLeftWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderRightWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderTopLeftRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderTopRightRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderTopWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    opacity: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    alignContent: "center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>[] | undefined;
    alignItems: import("react-native").FlexAlignType | import("moti").SequenceItem<import("react-native").FlexAlignType | undefined>[] | undefined;
    alignSelf: "auto" | import("react-native").FlexAlignType | import("moti").SequenceItem<"auto" | import("react-native").FlexAlignType | undefined>[] | undefined;
    aspectRatio: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    borderEndWidth: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    borderStartWidth: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    bottom: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    display: "none" | "flex" | import("moti").SequenceItem<"none" | "flex" | undefined>[] | undefined;
    end: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    flex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    flexBasis: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    flexDirection: "row" | "column" | "row-reverse" | "column-reverse" | import("moti").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | undefined;
    flexGrow: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    flexShrink: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    flexWrap: "wrap" | "nowrap" | "wrap-reverse" | import("moti").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | undefined;
    height: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    justifyContent: "center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>[] | undefined;
    left: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    margin: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginBottom: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginEnd: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginHorizontal: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginLeft: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginRight: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginStart: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginTop: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    marginVertical: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    maxHeight: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    maxWidth: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    minHeight: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    minWidth: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    overflow: "scroll" | "visible" | "hidden" | import("moti").SequenceItem<"scroll" | "visible" | "hidden" | undefined>[] | undefined;
    padding: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingBottom: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingEnd: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingHorizontal: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingLeft: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingRight: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingStart: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingTop: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    paddingVertical: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    position: "absolute" | "relative" | import("moti").SequenceItem<"absolute" | "relative" | undefined>[] | undefined;
    right: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    start: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    top: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    width: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
    zIndex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    direction: "inherit" | "ltr" | "rtl" | import("moti").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | undefined;
    shadowColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
    shadowOffset: {
        width: number;
        height: number;
    } | import("moti").SequenceItem<{
        width: number;
        height: number;
    } | undefined>[] | undefined;
    shadowOpacity: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    shadowRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
    transformMatrix: number[] | import("moti").SequenceItem<number[] | undefined>[] | undefined;
    rotation: number | import("moti").SequenceItem<number | undefined>[] | undefined;
} & {
    scaleX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined;
    scaleY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined;
    translateX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined;
    translateY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined;
    perspective?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined;
    rotate?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined;
    rotateX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined;
    rotateY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined;
    rotateZ?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined;
    scale?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined;
    skewX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined;
    skewY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined;
} & import("moti").StyleValueWithSequenceArraysWithTransform>, {
    backfaceVisibility?: "visible" | "hidden" | import("moti").SequenceItem<"visible" | "hidden" | undefined>[] | {
        value: "visible" | "hidden" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"visible" | "hidden" | import("moti").SequenceItem<"visible" | "hidden" | undefined>[] | undefined>;
    } | undefined;
    backgroundColor?: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | {
        value: import("react-native").ColorValue | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined>;
    } | undefined;
    borderBottomLeftRadius?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderBottomRightRadius?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderBottomWidth?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderColor?: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | {
        value: import("react-native").ColorValue | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined>;
    } | undefined;
    borderLeftWidth?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderRadius?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderRightWidth?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderTopLeftRadius?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderTopRightRadius?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderTopWidth?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderWidth?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    opacity?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    alignContent?: "center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>[] | {
        value: "center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>[] | undefined>;
    } | undefined;
    alignItems?: import("react-native").FlexAlignType | import("moti").SequenceItem<import("react-native").FlexAlignType | undefined>[] | {
        value: import("react-native").FlexAlignType | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<import("react-native").FlexAlignType | import("moti").SequenceItem<import("react-native").FlexAlignType | undefined>[] | undefined>;
    } | undefined;
    alignSelf?: "auto" | import("react-native").FlexAlignType | import("moti").SequenceItem<"auto" | import("react-native").FlexAlignType | undefined>[] | {
        value: "auto" | import("react-native").FlexAlignType | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"auto" | import("react-native").FlexAlignType | import("moti").SequenceItem<"auto" | import("react-native").FlexAlignType | undefined>[] | undefined>;
    } | undefined;
    aspectRatio?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    borderEndWidth?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    borderStartWidth?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    bottom?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    display?: "none" | "flex" | import("moti").SequenceItem<"none" | "flex" | undefined>[] | {
        value: "none" | "flex" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"none" | "flex" | import("moti").SequenceItem<"none" | "flex" | undefined>[] | undefined>;
    } | undefined;
    end?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    flex?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    flexBasis?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    flexDirection?: "row" | "column" | "row-reverse" | "column-reverse" | import("moti").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | {
        value: "row" | "column" | "row-reverse" | "column-reverse" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"row" | "column" | "row-reverse" | "column-reverse" | import("moti").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | undefined>;
    } | undefined;
    flexGrow?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    flexShrink?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    flexWrap?: "wrap" | "nowrap" | "wrap-reverse" | import("moti").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | {
        value: "wrap" | "nowrap" | "wrap-reverse" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"wrap" | "nowrap" | "wrap-reverse" | import("moti").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | undefined>;
    } | undefined;
    height?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    justifyContent?: "center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>[] | {
        value: "center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>[] | undefined>;
    } | undefined;
    left?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    margin?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginBottom?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginEnd?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginHorizontal?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginLeft?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginRight?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginStart?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginTop?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    marginVertical?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    maxHeight?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    maxWidth?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    minHeight?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    minWidth?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    overflow?: "scroll" | "visible" | "hidden" | import("moti").SequenceItem<"scroll" | "visible" | "hidden" | undefined>[] | {
        value: "scroll" | "visible" | "hidden" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"scroll" | "visible" | "hidden" | import("moti").SequenceItem<"scroll" | "visible" | "hidden" | undefined>[] | undefined>;
    } | undefined;
    padding?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingBottom?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingEnd?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingHorizontal?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingLeft?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingRight?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingStart?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingTop?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    paddingVertical?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    position?: "absolute" | "relative" | import("moti").SequenceItem<"absolute" | "relative" | undefined>[] | {
        value: "absolute" | "relative" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"absolute" | "relative" | import("moti").SequenceItem<"absolute" | "relative" | undefined>[] | undefined>;
    } | undefined;
    right?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    start?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    top?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    width?: string | number | import("moti").SequenceItem<string | number | undefined>[] | {
        value: string | number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined>;
    } | undefined;
    zIndex?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    direction?: "inherit" | "ltr" | "rtl" | import("moti").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | {
        value: "inherit" | "ltr" | "rtl" | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<"inherit" | "ltr" | "rtl" | import("moti").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | undefined>;
    } | undefined;
    shadowColor?: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | {
        value: import("react-native").ColorValue | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined>;
    } | undefined;
    shadowOffset?: {
        width: number;
        height: number;
    } | import("moti").SequenceItem<{
        width: number;
        height: number;
    } | undefined>[] | {
        value: undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<{
            width: number;
            height: number;
        } | import("moti").SequenceItem<{
            width: number;
            height: number;
        } | undefined>[] | undefined>;
    } | undefined;
    shadowOpacity?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    shadowRadius?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    transformMatrix?: number[] | import("moti").SequenceItem<number[] | undefined>[] | {
        value: undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number[] | import("moti").SequenceItem<number[] | undefined>[] | undefined>;
    } | undefined;
    rotation?: number | import("moti").SequenceItem<number | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | import("moti").SequenceItem<number | undefined>[] | undefined>;
    } | undefined;
    scaleX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    scaleY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    translateX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    translateY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    perspective?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    rotate?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | {
        value: string | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    rotateX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | {
        value: string | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    rotateY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | {
        value: string | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    rotateZ?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | {
        value: string | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    scale?: number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | {
        value: number | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<number | (string & {}) | import("moti").SequenceItem<number | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    skewX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | {
        value: string | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    skewY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | {
        value: string | undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<string | (string & {}) | import("moti").SequenceItem<string | (string & {}) | undefined>[] | undefined>;
    } | undefined;
    transform?: Partial<{
        scaleX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
        scaleY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
        translateX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
        translateY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
        perspective?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
        rotate?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
        rotateX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
        rotateY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
        rotateZ?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
        scale?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
        skewX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
        skewY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
    } & import("moti").StyleValueWithSequenceArraysWithTransform>[] | {
        value: undefined;
        onDidAnimate: import("moti").InlineOnDidAnimate<Partial<{
            scaleX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
            scaleY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
            translateX?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
            translateY?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
            perspective?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
            rotate?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
            rotateX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
            rotateY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
            rotateZ?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
            scale?: number | (string & {}) | import("moti").SequenceItem<number | (string & {})>[] | undefined;
            skewX?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
            skewY?: string | (string & {}) | import("moti").SequenceItem<string | (string & {})>[] | undefined;
        } & import("moti").StyleValueWithSequenceArraysWithTransform>[] | undefined>;
    } | undefined;
}> & {
    children?: React.ReactNode;
} & React.RefAttributes<unknown>, "delay" | "stylePriority" | "onDidAnimate" | "animateInitialState"> & {
    from?: boolean | (Omit<Partial<{
        end: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        start: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        elevation: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        margin: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginTop: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginRight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginBottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginLeft: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginHorizontal: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginVertical: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginStart: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginEnd: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        padding: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingTop: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingRight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingBottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingLeft: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingHorizontal: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingVertical: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingStart: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingEnd: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        width: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        height: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        minWidth: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        maxWidth: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        minHeight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        maxHeight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        overflow: "scroll" | "visible" | "hidden" | import("moti").SequenceItem<"scroll" | "visible" | "hidden" | undefined>[] | undefined;
        aspectRatio: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
        alignContent: "center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>[] | undefined;
        alignItems: import("react-native").FlexAlignType | import("moti").SequenceItem<import("react-native").FlexAlignType | undefined>[] | undefined;
        alignSelf: "auto" | import("react-native").FlexAlignType | import("moti").SequenceItem<"auto" | import("react-native").FlexAlignType | undefined>[] | undefined;
        justifyContent: "center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>[] | undefined;
        flex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexBasis: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        flexDirection: "row" | "column" | "row-reverse" | "column-reverse" | import("moti").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | undefined;
        flexGrow: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexShrink: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexWrap: "wrap" | "nowrap" | "wrap-reverse" | import("moti").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | undefined;
        transformMatrix: number[] | import("moti").SequenceItem<number[] | undefined>[] | undefined;
        rotation: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        position: "absolute" | "relative" | import("moti").SequenceItem<"absolute" | "relative" | undefined>[] | undefined;
        top: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        right: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        bottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        left: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        borderBottomWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderLeftWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderRightWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderStyle: "solid" | "dotted" | "dashed" | import("moti").SequenceItem<"solid" | "dotted" | "dashed" | undefined>[] | undefined;
        borderTopWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderStartWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderEndWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderTopColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderRightColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderLeftColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBottomColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderStartColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderEndColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomLeftRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomRightRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopLeftRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopRightRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        shadowOpacity: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        shadowOffset: Readonly<{
            width: number;
            height: number;
        }> | import("moti").SequenceItem<Readonly<{
            width: number;
            height: number;
        }> | undefined>[] | undefined;
        shadowRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        display: "none" | "flex" | import("moti").SequenceItem<"none" | "flex" | undefined>[] | undefined;
        backfaceVisibility: "visible" | "hidden" | import("moti").SequenceItem<"visible" | "hidden" | undefined>[] | undefined;
        backgroundColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockEndColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockStartColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderCurve: "circular" | "continuous" | import("moti").SequenceItem<"circular" | "continuous" | undefined>[] | undefined;
        borderEndEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderEndStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderStartEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderStartStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        opacity: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        pointerEvents: "auto" | "none" | "box-none" | "box-only" | import("moti").SequenceItem<"auto" | "none" | "box-none" | "box-only" | undefined>[] | undefined;
        rowGap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        gap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        columnGap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        zIndex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        direction: "inherit" | "ltr" | "rtl" | import("moti").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | undefined;
        shadowColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
    } & {
        scaleX?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        scaleY?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        translateX?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        translateY?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        perspective?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        rotate?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateX?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateY?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateZ?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        scale?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        skewX?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        skewY?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
    } & import("moti").StyleValueWithSequenceArraysWithTransform>, keyof import("react-native").ViewStyle> & Omit<import("react-native").ViewStyle, "p" | "ms" | "end" | "start" | "m" | "py" | "pl" | "elevation" | "margin" | "marginTop" | "marginRight" | "marginBottom" | "marginLeft" | "marginHorizontal" | "marginVertical" | "marginStart" | "marginEnd" | "padding" | "paddingTop" | "paddingRight" | "paddingBottom" | "paddingLeft" | "paddingHorizontal" | "paddingVertical" | "paddingStart" | "paddingEnd" | "width" | "height" | "minWidth" | "maxWidth" | "minHeight" | "maxHeight" | "mt" | "mr" | "mb" | "ml" | "mx" | "my" | "me" | "pt" | "pr" | "pb" | "px" | "ps" | "pe" | "overflow" | "aspectRatio" | "alignContent" | "alignItems" | "alignSelf" | "justifyContent" | "flex" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "w" | "h" | "minW" | "maxW" | "minH" | "maxH" | "transform" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "position" | "top" | "right" | "bottom" | "left" | "borderBottomWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStyle" | "borderTopWidth" | "borderStartWidth" | "borderEndWidth" | "borderWidth" | "borderColor" | "borderTopColor" | "borderRightColor" | "borderLeftColor" | "borderBottomColor" | "borderStartColor" | "borderEndColor" | "borderRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderBottomStartRadius" | "borderBottomEndRadius" | "borderTopStartRadius" | "borderTopEndRadius" | "shadowOpacity" | "shadowOffset" | "shadowRadius" | "opacity" | "zIndex" | "shadowColor" | keyof import("../../../theme").BackgroundColorProps | "visible" | "boxShadow"> & import("../../../theme").BackgroundColorProps & import("../../../theme").OpacityProps & import("../../../theme").VisibleProps & {
        width?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        height?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        overflow?: ResponsiveValue<"scroll" | "visible" | "hidden" | undefined>;
        aspectRatio?: ResponsiveValue<string | number | undefined>;
        alignContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>;
        alignItems?: ResponsiveValue<import("react-native").FlexAlignType | undefined>;
        alignSelf?: ResponsiveValue<"auto" | import("react-native").FlexAlignType | undefined>;
        justifyContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>;
        flex?: ResponsiveValue<number | undefined>;
        flexBasis?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        flexDirection?: ResponsiveValue<"row" | "column" | "row-reverse" | "column-reverse" | undefined>;
        flexGrow?: ResponsiveValue<number | undefined>;
        flexShrink?: ResponsiveValue<number | undefined>;
        flexWrap?: ResponsiveValue<"wrap" | "nowrap" | "wrap-reverse" | undefined>;
    } & {
        readonly w?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly h?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & import("../../../theme").TransformProps & {
        margin?: ResponsiveValue<string | number> | undefined;
        marginTop?: ResponsiveValue<string | number> | undefined;
        marginRight?: ResponsiveValue<string | number> | undefined;
        marginBottom?: ResponsiveValue<string | number> | undefined;
        marginLeft?: ResponsiveValue<string | number> | undefined;
        marginHorizontal?: ResponsiveValue<string | number> | undefined;
        marginVertical?: ResponsiveValue<string | number> | undefined;
        marginStart?: ResponsiveValue<string | number> | undefined;
        marginEnd?: ResponsiveValue<string | number> | undefined;
        padding?: ResponsiveValue<string | number> | undefined;
        paddingTop?: ResponsiveValue<string | number> | undefined;
        paddingRight?: ResponsiveValue<string | number> | undefined;
        paddingBottom?: ResponsiveValue<string | number> | undefined;
        paddingLeft?: ResponsiveValue<string | number> | undefined;
        paddingHorizontal?: ResponsiveValue<string | number> | undefined;
        paddingVertical?: ResponsiveValue<string | number> | undefined;
        paddingStart?: ResponsiveValue<string | number> | undefined;
        paddingEnd?: ResponsiveValue<string | number> | undefined;
    } & {
        readonly m?: ResponsiveValue<string | number> | undefined;
        readonly mt?: ResponsiveValue<string | number> | undefined;
        readonly mr?: ResponsiveValue<string | number> | undefined;
        readonly mb?: ResponsiveValue<string | number> | undefined;
        readonly ml?: ResponsiveValue<string | number> | undefined;
        readonly mx?: ResponsiveValue<string | number> | undefined;
        readonly my?: ResponsiveValue<string | number> | undefined;
        readonly ms?: ResponsiveValue<string | number> | undefined;
        readonly me?: ResponsiveValue<string | number> | undefined;
        readonly p?: ResponsiveValue<string | number> | undefined;
        readonly pt?: ResponsiveValue<string | number> | undefined;
        readonly pr?: ResponsiveValue<string | number> | undefined;
        readonly pb?: ResponsiveValue<string | number> | undefined;
        readonly pl?: ResponsiveValue<string | number> | undefined;
        readonly px?: ResponsiveValue<string | number> | undefined;
        readonly py?: ResponsiveValue<string | number> | undefined;
        readonly ps?: ResponsiveValue<string | number> | undefined;
        readonly pe?: ResponsiveValue<string | number> | undefined;
    } & {
        borderBottomWidth?: ResponsiveValue<number | undefined>;
        borderLeftWidth?: ResponsiveValue<number | undefined>;
        borderRightWidth?: ResponsiveValue<number | undefined>;
        borderStyle?: ResponsiveValue<"solid" | "dotted" | "dashed" | undefined>;
        borderTopWidth?: ResponsiveValue<number | undefined>;
        borderStartWidth?: ResponsiveValue<number | undefined>;
        borderEndWidth?: ResponsiveValue<number | undefined>;
        borderWidth?: ResponsiveValue<number | undefined>;
    } & {
        borderColor?: ResponsiveValue<PaletteColors> | undefined;
        borderTopColor?: ResponsiveValue<PaletteColors> | undefined;
        borderRightColor?: ResponsiveValue<PaletteColors> | undefined;
        borderLeftColor?: ResponsiveValue<PaletteColors> | undefined;
        borderBottomColor?: ResponsiveValue<PaletteColors> | undefined;
        borderStartColor?: ResponsiveValue<PaletteColors> | undefined;
        borderEndColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        borderRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomRightRadius?: ResponsiveValue<string | number> | undefined;
        borderTopLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderTopRightRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomStartRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomEndRadius?: ResponsiveValue<string | number> | undefined;
        borderTopStartRadius?: ResponsiveValue<string | number> | undefined;
        borderTopEndRadius?: ResponsiveValue<string | number> | undefined;
    } & {
        shadowOpacity?: ResponsiveValue<import("react-native").AnimatableNumericValue | undefined>;
        shadowOffset?: ResponsiveValue<Readonly<{
            width: number;
            height: number;
        }> | undefined>;
        shadowRadius?: ResponsiveValue<number | undefined>;
        elevation?: ResponsiveValue<number | undefined>;
    } & {
        boxShadow?: ResponsiveValue<string | number> | undefined;
        shadowColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        position?: ResponsiveValue<"absolute" | "relative" | undefined>;
        top?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        right?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        bottom?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        left?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        start?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        end?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & {
        zIndex?: ResponsiveValue<string | number> | undefined;
    }) | undefined;
    animate?: ((Omit<Partial<{
        end: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        start: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        elevation: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        margin: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginTop: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginRight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginBottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginLeft: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginHorizontal: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginVertical: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginStart: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginEnd: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        padding: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingTop: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingRight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingBottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingLeft: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingHorizontal: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingVertical: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingStart: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingEnd: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        width: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        height: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        minWidth: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        maxWidth: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        minHeight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        maxHeight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        overflow: "scroll" | "visible" | "hidden" | import("moti").SequenceItem<"scroll" | "visible" | "hidden" | undefined>[] | undefined;
        aspectRatio: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
        alignContent: "center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>[] | undefined;
        alignItems: import("react-native").FlexAlignType | import("moti").SequenceItem<import("react-native").FlexAlignType | undefined>[] | undefined;
        alignSelf: "auto" | import("react-native").FlexAlignType | import("moti").SequenceItem<"auto" | import("react-native").FlexAlignType | undefined>[] | undefined;
        justifyContent: "center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>[] | undefined;
        flex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexBasis: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        flexDirection: "row" | "column" | "row-reverse" | "column-reverse" | import("moti").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | undefined;
        flexGrow: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexShrink: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexWrap: "wrap" | "nowrap" | "wrap-reverse" | import("moti").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | undefined;
        transformMatrix: number[] | import("moti").SequenceItem<number[] | undefined>[] | undefined;
        rotation: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        position: "absolute" | "relative" | import("moti").SequenceItem<"absolute" | "relative" | undefined>[] | undefined;
        top: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        right: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        bottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        left: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        borderBottomWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderLeftWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderRightWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderStyle: "solid" | "dotted" | "dashed" | import("moti").SequenceItem<"solid" | "dotted" | "dashed" | undefined>[] | undefined;
        borderTopWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderStartWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderEndWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderTopColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderRightColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderLeftColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBottomColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderStartColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderEndColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomLeftRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomRightRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopLeftRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopRightRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        shadowOpacity: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        shadowOffset: Readonly<{
            width: number;
            height: number;
        }> | import("moti").SequenceItem<Readonly<{
            width: number;
            height: number;
        }> | undefined>[] | undefined;
        shadowRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        display: "none" | "flex" | import("moti").SequenceItem<"none" | "flex" | undefined>[] | undefined;
        backfaceVisibility: "visible" | "hidden" | import("moti").SequenceItem<"visible" | "hidden" | undefined>[] | undefined;
        backgroundColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockEndColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockStartColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderCurve: "circular" | "continuous" | import("moti").SequenceItem<"circular" | "continuous" | undefined>[] | undefined;
        borderEndEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderEndStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderStartEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderStartStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        opacity: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        pointerEvents: "auto" | "none" | "box-none" | "box-only" | import("moti").SequenceItem<"auto" | "none" | "box-none" | "box-only" | undefined>[] | undefined;
        rowGap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        gap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        columnGap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        zIndex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        direction: "inherit" | "ltr" | "rtl" | import("moti").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | undefined;
        shadowColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
    } & {
        scaleX?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        scaleY?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        translateX?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        translateY?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        perspective?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        rotate?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateX?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateY?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateZ?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        scale?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        skewX?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        skewY?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
    } & import("moti").StyleValueWithSequenceArraysWithTransform>, keyof import("react-native").ViewStyle> & Omit<import("react-native").ViewStyle, "p" | "ms" | "end" | "start" | "m" | "py" | "pl" | "elevation" | "margin" | "marginTop" | "marginRight" | "marginBottom" | "marginLeft" | "marginHorizontal" | "marginVertical" | "marginStart" | "marginEnd" | "padding" | "paddingTop" | "paddingRight" | "paddingBottom" | "paddingLeft" | "paddingHorizontal" | "paddingVertical" | "paddingStart" | "paddingEnd" | "width" | "height" | "minWidth" | "maxWidth" | "minHeight" | "maxHeight" | "mt" | "mr" | "mb" | "ml" | "mx" | "my" | "me" | "pt" | "pr" | "pb" | "px" | "ps" | "pe" | "overflow" | "aspectRatio" | "alignContent" | "alignItems" | "alignSelf" | "justifyContent" | "flex" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "w" | "h" | "minW" | "maxW" | "minH" | "maxH" | "transform" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "position" | "top" | "right" | "bottom" | "left" | "borderBottomWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStyle" | "borderTopWidth" | "borderStartWidth" | "borderEndWidth" | "borderWidth" | "borderColor" | "borderTopColor" | "borderRightColor" | "borderLeftColor" | "borderBottomColor" | "borderStartColor" | "borderEndColor" | "borderRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderBottomStartRadius" | "borderBottomEndRadius" | "borderTopStartRadius" | "borderTopEndRadius" | "shadowOpacity" | "shadowOffset" | "shadowRadius" | "opacity" | "zIndex" | "shadowColor" | keyof import("../../../theme").BackgroundColorProps | "visible" | "boxShadow"> & import("../../../theme").BackgroundColorProps & import("../../../theme").OpacityProps & import("../../../theme").VisibleProps & {
        width?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        height?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        overflow?: ResponsiveValue<"scroll" | "visible" | "hidden" | undefined>;
        aspectRatio?: ResponsiveValue<string | number | undefined>;
        alignContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>;
        alignItems?: ResponsiveValue<import("react-native").FlexAlignType | undefined>;
        alignSelf?: ResponsiveValue<"auto" | import("react-native").FlexAlignType | undefined>;
        justifyContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>;
        flex?: ResponsiveValue<number | undefined>;
        flexBasis?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        flexDirection?: ResponsiveValue<"row" | "column" | "row-reverse" | "column-reverse" | undefined>;
        flexGrow?: ResponsiveValue<number | undefined>;
        flexShrink?: ResponsiveValue<number | undefined>;
        flexWrap?: ResponsiveValue<"wrap" | "nowrap" | "wrap-reverse" | undefined>;
    } & {
        readonly w?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly h?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & import("../../../theme").TransformProps & {
        margin?: ResponsiveValue<string | number> | undefined;
        marginTop?: ResponsiveValue<string | number> | undefined;
        marginRight?: ResponsiveValue<string | number> | undefined;
        marginBottom?: ResponsiveValue<string | number> | undefined;
        marginLeft?: ResponsiveValue<string | number> | undefined;
        marginHorizontal?: ResponsiveValue<string | number> | undefined;
        marginVertical?: ResponsiveValue<string | number> | undefined;
        marginStart?: ResponsiveValue<string | number> | undefined;
        marginEnd?: ResponsiveValue<string | number> | undefined;
        padding?: ResponsiveValue<string | number> | undefined;
        paddingTop?: ResponsiveValue<string | number> | undefined;
        paddingRight?: ResponsiveValue<string | number> | undefined;
        paddingBottom?: ResponsiveValue<string | number> | undefined;
        paddingLeft?: ResponsiveValue<string | number> | undefined;
        paddingHorizontal?: ResponsiveValue<string | number> | undefined;
        paddingVertical?: ResponsiveValue<string | number> | undefined;
        paddingStart?: ResponsiveValue<string | number> | undefined;
        paddingEnd?: ResponsiveValue<string | number> | undefined;
    } & {
        readonly m?: ResponsiveValue<string | number> | undefined;
        readonly mt?: ResponsiveValue<string | number> | undefined;
        readonly mr?: ResponsiveValue<string | number> | undefined;
        readonly mb?: ResponsiveValue<string | number> | undefined;
        readonly ml?: ResponsiveValue<string | number> | undefined;
        readonly mx?: ResponsiveValue<string | number> | undefined;
        readonly my?: ResponsiveValue<string | number> | undefined;
        readonly ms?: ResponsiveValue<string | number> | undefined;
        readonly me?: ResponsiveValue<string | number> | undefined;
        readonly p?: ResponsiveValue<string | number> | undefined;
        readonly pt?: ResponsiveValue<string | number> | undefined;
        readonly pr?: ResponsiveValue<string | number> | undefined;
        readonly pb?: ResponsiveValue<string | number> | undefined;
        readonly pl?: ResponsiveValue<string | number> | undefined;
        readonly px?: ResponsiveValue<string | number> | undefined;
        readonly py?: ResponsiveValue<string | number> | undefined;
        readonly ps?: ResponsiveValue<string | number> | undefined;
        readonly pe?: ResponsiveValue<string | number> | undefined;
    } & {
        borderBottomWidth?: ResponsiveValue<number | undefined>;
        borderLeftWidth?: ResponsiveValue<number | undefined>;
        borderRightWidth?: ResponsiveValue<number | undefined>;
        borderStyle?: ResponsiveValue<"solid" | "dotted" | "dashed" | undefined>;
        borderTopWidth?: ResponsiveValue<number | undefined>;
        borderStartWidth?: ResponsiveValue<number | undefined>;
        borderEndWidth?: ResponsiveValue<number | undefined>;
        borderWidth?: ResponsiveValue<number | undefined>;
    } & {
        borderColor?: ResponsiveValue<PaletteColors> | undefined;
        borderTopColor?: ResponsiveValue<PaletteColors> | undefined;
        borderRightColor?: ResponsiveValue<PaletteColors> | undefined;
        borderLeftColor?: ResponsiveValue<PaletteColors> | undefined;
        borderBottomColor?: ResponsiveValue<PaletteColors> | undefined;
        borderStartColor?: ResponsiveValue<PaletteColors> | undefined;
        borderEndColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        borderRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomRightRadius?: ResponsiveValue<string | number> | undefined;
        borderTopLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderTopRightRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomStartRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomEndRadius?: ResponsiveValue<string | number> | undefined;
        borderTopStartRadius?: ResponsiveValue<string | number> | undefined;
        borderTopEndRadius?: ResponsiveValue<string | number> | undefined;
    } & {
        shadowOpacity?: ResponsiveValue<import("react-native").AnimatableNumericValue | undefined>;
        shadowOffset?: ResponsiveValue<Readonly<{
            width: number;
            height: number;
        }> | undefined>;
        shadowRadius?: ResponsiveValue<number | undefined>;
        elevation?: ResponsiveValue<number | undefined>;
    } & {
        boxShadow?: ResponsiveValue<string | number> | undefined;
        shadowColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        position?: ResponsiveValue<"absolute" | "relative" | undefined>;
        top?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        right?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        bottom?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        left?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        start?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        end?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & {
        zIndex?: ResponsiveValue<string | number> | undefined;
    }) | import("react-native-reanimated").SharedValue<Omit<Partial<{
        end: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        start: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        elevation: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        margin: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginTop: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginRight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginBottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginLeft: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginHorizontal: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginVertical: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginStart: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        marginEnd: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        padding: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingTop: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingRight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingBottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingLeft: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingHorizontal: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingVertical: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingStart: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        paddingEnd: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        width: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        height: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        minWidth: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        maxWidth: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        minHeight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        maxHeight: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        overflow: "scroll" | "visible" | "hidden" | import("moti").SequenceItem<"scroll" | "visible" | "hidden" | undefined>[] | undefined;
        aspectRatio: string | number | import("moti").SequenceItem<string | number | undefined>[] | undefined;
        alignContent: "center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>[] | undefined;
        alignItems: import("react-native").FlexAlignType | import("moti").SequenceItem<import("react-native").FlexAlignType | undefined>[] | undefined;
        alignSelf: "auto" | import("react-native").FlexAlignType | import("moti").SequenceItem<"auto" | import("react-native").FlexAlignType | undefined>[] | undefined;
        justifyContent: "center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | import("moti").SequenceItem<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>[] | undefined;
        flex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexBasis: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        flexDirection: "row" | "column" | "row-reverse" | "column-reverse" | import("moti").SequenceItem<"row" | "column" | "row-reverse" | "column-reverse" | undefined>[] | undefined;
        flexGrow: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexShrink: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        flexWrap: "wrap" | "nowrap" | "wrap-reverse" | import("moti").SequenceItem<"wrap" | "nowrap" | "wrap-reverse" | undefined>[] | undefined;
        transformMatrix: number[] | import("moti").SequenceItem<number[] | undefined>[] | undefined;
        rotation: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        position: "absolute" | "relative" | import("moti").SequenceItem<"absolute" | "relative" | undefined>[] | undefined;
        top: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        right: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        bottom: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        left: import("react-native").DimensionValue | import("moti").SequenceItem<import("react-native").DimensionValue | undefined>[] | undefined;
        borderBottomWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderLeftWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderRightWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderStyle: "solid" | "dotted" | "dashed" | import("moti").SequenceItem<"solid" | "dotted" | "dashed" | undefined>[] | undefined;
        borderTopWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderStartWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderEndWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderWidth: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        borderColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderTopColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderRightColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderLeftColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBottomColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderStartColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderEndColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomLeftRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomRightRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopLeftRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopRightRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderBottomEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderTopEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        shadowOpacity: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        shadowOffset: Readonly<{
            width: number;
            height: number;
        }> | import("moti").SequenceItem<Readonly<{
            width: number;
            height: number;
        }> | undefined>[] | undefined;
        shadowRadius: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        display: "none" | "flex" | import("moti").SequenceItem<"none" | "flex" | undefined>[] | undefined;
        backfaceVisibility: "visible" | "hidden" | import("moti").SequenceItem<"visible" | "hidden" | undefined>[] | undefined;
        backgroundColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockEndColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderBlockStartColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
        borderCurve: "circular" | "continuous" | import("moti").SequenceItem<"circular" | "continuous" | undefined>[] | undefined;
        borderEndEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderEndStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderStartEndRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        borderStartStartRadius: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        opacity: import("react-native").AnimatableNumericValue | import("moti").SequenceItem<import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        pointerEvents: "auto" | "none" | "box-none" | "box-only" | import("moti").SequenceItem<"auto" | "none" | "box-none" | "box-only" | undefined>[] | undefined;
        rowGap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        gap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        columnGap: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        zIndex: number | import("moti").SequenceItem<number | undefined>[] | undefined;
        direction: "inherit" | "ltr" | "rtl" | import("moti").SequenceItem<"inherit" | "ltr" | "rtl" | undefined>[] | undefined;
        shadowColor: import("react-native").ColorValue | import("moti").SequenceItem<import("react-native").ColorValue | undefined>[] | undefined;
    } & {
        scaleX?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        scaleY?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        translateX?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        translateY?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        perspective?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        rotate?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateX?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateY?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        rotateZ?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        scale?: (string & {}) | import("react-native").AnimatableNumericValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableNumericValue | undefined>[] | undefined;
        skewX?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
        skewY?: (string & {}) | import("react-native").AnimatableStringValue | import("moti").SequenceItem<(string & {}) | import("react-native").AnimatableStringValue | undefined>[] | undefined;
    } & import("moti").StyleValueWithSequenceArraysWithTransform>, keyof import("react-native").ViewStyle> & Omit<import("react-native").ViewStyle, "p" | "ms" | "end" | "start" | "m" | "py" | "pl" | "elevation" | "margin" | "marginTop" | "marginRight" | "marginBottom" | "marginLeft" | "marginHorizontal" | "marginVertical" | "marginStart" | "marginEnd" | "padding" | "paddingTop" | "paddingRight" | "paddingBottom" | "paddingLeft" | "paddingHorizontal" | "paddingVertical" | "paddingStart" | "paddingEnd" | "width" | "height" | "minWidth" | "maxWidth" | "minHeight" | "maxHeight" | "mt" | "mr" | "mb" | "ml" | "mx" | "my" | "me" | "pt" | "pr" | "pb" | "px" | "ps" | "pe" | "overflow" | "aspectRatio" | "alignContent" | "alignItems" | "alignSelf" | "justifyContent" | "flex" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "w" | "h" | "minW" | "maxW" | "minH" | "maxH" | "transform" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "position" | "top" | "right" | "bottom" | "left" | "borderBottomWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStyle" | "borderTopWidth" | "borderStartWidth" | "borderEndWidth" | "borderWidth" | "borderColor" | "borderTopColor" | "borderRightColor" | "borderLeftColor" | "borderBottomColor" | "borderStartColor" | "borderEndColor" | "borderRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderBottomStartRadius" | "borderBottomEndRadius" | "borderTopStartRadius" | "borderTopEndRadius" | "shadowOpacity" | "shadowOffset" | "shadowRadius" | "opacity" | "zIndex" | "shadowColor" | keyof import("../../../theme").BackgroundColorProps | "visible" | "boxShadow"> & import("../../../theme").BackgroundColorProps & import("../../../theme").OpacityProps & import("../../../theme").VisibleProps & {
        width?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        height?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        overflow?: ResponsiveValue<"scroll" | "visible" | "hidden" | undefined>;
        aspectRatio?: ResponsiveValue<string | number | undefined>;
        alignContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>;
        alignItems?: ResponsiveValue<import("react-native").FlexAlignType | undefined>;
        alignSelf?: ResponsiveValue<"auto" | import("react-native").FlexAlignType | undefined>;
        justifyContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>;
        flex?: ResponsiveValue<number | undefined>;
        flexBasis?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        flexDirection?: ResponsiveValue<"row" | "column" | "row-reverse" | "column-reverse" | undefined>;
        flexGrow?: ResponsiveValue<number | undefined>;
        flexShrink?: ResponsiveValue<number | undefined>;
        flexWrap?: ResponsiveValue<"wrap" | "nowrap" | "wrap-reverse" | undefined>;
    } & {
        readonly w?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly h?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & import("../../../theme").TransformProps & {
        margin?: ResponsiveValue<string | number> | undefined;
        marginTop?: ResponsiveValue<string | number> | undefined;
        marginRight?: ResponsiveValue<string | number> | undefined;
        marginBottom?: ResponsiveValue<string | number> | undefined;
        marginLeft?: ResponsiveValue<string | number> | undefined;
        marginHorizontal?: ResponsiveValue<string | number> | undefined;
        marginVertical?: ResponsiveValue<string | number> | undefined;
        marginStart?: ResponsiveValue<string | number> | undefined;
        marginEnd?: ResponsiveValue<string | number> | undefined;
        padding?: ResponsiveValue<string | number> | undefined;
        paddingTop?: ResponsiveValue<string | number> | undefined;
        paddingRight?: ResponsiveValue<string | number> | undefined;
        paddingBottom?: ResponsiveValue<string | number> | undefined;
        paddingLeft?: ResponsiveValue<string | number> | undefined;
        paddingHorizontal?: ResponsiveValue<string | number> | undefined;
        paddingVertical?: ResponsiveValue<string | number> | undefined;
        paddingStart?: ResponsiveValue<string | number> | undefined;
        paddingEnd?: ResponsiveValue<string | number> | undefined;
    } & {
        readonly m?: ResponsiveValue<string | number> | undefined;
        readonly mt?: ResponsiveValue<string | number> | undefined;
        readonly mr?: ResponsiveValue<string | number> | undefined;
        readonly mb?: ResponsiveValue<string | number> | undefined;
        readonly ml?: ResponsiveValue<string | number> | undefined;
        readonly mx?: ResponsiveValue<string | number> | undefined;
        readonly my?: ResponsiveValue<string | number> | undefined;
        readonly ms?: ResponsiveValue<string | number> | undefined;
        readonly me?: ResponsiveValue<string | number> | undefined;
        readonly p?: ResponsiveValue<string | number> | undefined;
        readonly pt?: ResponsiveValue<string | number> | undefined;
        readonly pr?: ResponsiveValue<string | number> | undefined;
        readonly pb?: ResponsiveValue<string | number> | undefined;
        readonly pl?: ResponsiveValue<string | number> | undefined;
        readonly px?: ResponsiveValue<string | number> | undefined;
        readonly py?: ResponsiveValue<string | number> | undefined;
        readonly ps?: ResponsiveValue<string | number> | undefined;
        readonly pe?: ResponsiveValue<string | number> | undefined;
    } & {
        borderBottomWidth?: ResponsiveValue<number | undefined>;
        borderLeftWidth?: ResponsiveValue<number | undefined>;
        borderRightWidth?: ResponsiveValue<number | undefined>;
        borderStyle?: ResponsiveValue<"solid" | "dotted" | "dashed" | undefined>;
        borderTopWidth?: ResponsiveValue<number | undefined>;
        borderStartWidth?: ResponsiveValue<number | undefined>;
        borderEndWidth?: ResponsiveValue<number | undefined>;
        borderWidth?: ResponsiveValue<number | undefined>;
    } & {
        borderColor?: ResponsiveValue<PaletteColors> | undefined;
        borderTopColor?: ResponsiveValue<PaletteColors> | undefined;
        borderRightColor?: ResponsiveValue<PaletteColors> | undefined;
        borderLeftColor?: ResponsiveValue<PaletteColors> | undefined;
        borderBottomColor?: ResponsiveValue<PaletteColors> | undefined;
        borderStartColor?: ResponsiveValue<PaletteColors> | undefined;
        borderEndColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        borderRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomRightRadius?: ResponsiveValue<string | number> | undefined;
        borderTopLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderTopRightRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomStartRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomEndRadius?: ResponsiveValue<string | number> | undefined;
        borderTopStartRadius?: ResponsiveValue<string | number> | undefined;
        borderTopEndRadius?: ResponsiveValue<string | number> | undefined;
    } & {
        shadowOpacity?: ResponsiveValue<import("react-native").AnimatableNumericValue | undefined>;
        shadowOffset?: ResponsiveValue<Readonly<{
            width: number;
            height: number;
        }> | undefined>;
        shadowRadius?: ResponsiveValue<number | undefined>;
        elevation?: ResponsiveValue<number | undefined>;
    } & {
        boxShadow?: ResponsiveValue<string | number> | undefined;
        shadowColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        position?: ResponsiveValue<"absolute" | "relative" | undefined>;
        top?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        right?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        bottom?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        left?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        start?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        end?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & {
        zIndex?: ResponsiveValue<string | number> | undefined;
    }>) | undefined;
    exit?: boolean | (Omit<import("moti").StyleValueWithReplacedTransforms<import("react-native").ViewStyle>, keyof import("react-native").ViewStyle> & Omit<import("react-native").ViewStyle, "p" | "ms" | "end" | "start" | "m" | "py" | "pl" | "elevation" | "margin" | "marginTop" | "marginRight" | "marginBottom" | "marginLeft" | "marginHorizontal" | "marginVertical" | "marginStart" | "marginEnd" | "padding" | "paddingTop" | "paddingRight" | "paddingBottom" | "paddingLeft" | "paddingHorizontal" | "paddingVertical" | "paddingStart" | "paddingEnd" | "width" | "height" | "minWidth" | "maxWidth" | "minHeight" | "maxHeight" | "mt" | "mr" | "mb" | "ml" | "mx" | "my" | "me" | "pt" | "pr" | "pb" | "px" | "ps" | "pe" | "overflow" | "aspectRatio" | "alignContent" | "alignItems" | "alignSelf" | "justifyContent" | "flex" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "w" | "h" | "minW" | "maxW" | "minH" | "maxH" | "transform" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "position" | "top" | "right" | "bottom" | "left" | "borderBottomWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStyle" | "borderTopWidth" | "borderStartWidth" | "borderEndWidth" | "borderWidth" | "borderColor" | "borderTopColor" | "borderRightColor" | "borderLeftColor" | "borderBottomColor" | "borderStartColor" | "borderEndColor" | "borderRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderBottomStartRadius" | "borderBottomEndRadius" | "borderTopStartRadius" | "borderTopEndRadius" | "shadowOpacity" | "shadowOffset" | "shadowRadius" | "opacity" | "zIndex" | "shadowColor" | keyof import("../../../theme").BackgroundColorProps | "visible" | "boxShadow"> & import("../../../theme").BackgroundColorProps & import("../../../theme").OpacityProps & import("../../../theme").VisibleProps & {
        width?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        height?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        overflow?: ResponsiveValue<"scroll" | "visible" | "hidden" | undefined>;
        aspectRatio?: ResponsiveValue<string | number | undefined>;
        alignContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>;
        alignItems?: ResponsiveValue<import("react-native").FlexAlignType | undefined>;
        alignSelf?: ResponsiveValue<"auto" | import("react-native").FlexAlignType | undefined>;
        justifyContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>;
        flex?: ResponsiveValue<number | undefined>;
        flexBasis?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        flexDirection?: ResponsiveValue<"row" | "column" | "row-reverse" | "column-reverse" | undefined>;
        flexGrow?: ResponsiveValue<number | undefined>;
        flexShrink?: ResponsiveValue<number | undefined>;
        flexWrap?: ResponsiveValue<"wrap" | "nowrap" | "wrap-reverse" | undefined>;
    } & {
        readonly w?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly h?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & import("../../../theme").TransformProps & {
        margin?: ResponsiveValue<string | number> | undefined;
        marginTop?: ResponsiveValue<string | number> | undefined;
        marginRight?: ResponsiveValue<string | number> | undefined;
        marginBottom?: ResponsiveValue<string | number> | undefined;
        marginLeft?: ResponsiveValue<string | number> | undefined;
        marginHorizontal?: ResponsiveValue<string | number> | undefined;
        marginVertical?: ResponsiveValue<string | number> | undefined;
        marginStart?: ResponsiveValue<string | number> | undefined;
        marginEnd?: ResponsiveValue<string | number> | undefined;
        padding?: ResponsiveValue<string | number> | undefined;
        paddingTop?: ResponsiveValue<string | number> | undefined;
        paddingRight?: ResponsiveValue<string | number> | undefined;
        paddingBottom?: ResponsiveValue<string | number> | undefined;
        paddingLeft?: ResponsiveValue<string | number> | undefined;
        paddingHorizontal?: ResponsiveValue<string | number> | undefined;
        paddingVertical?: ResponsiveValue<string | number> | undefined;
        paddingStart?: ResponsiveValue<string | number> | undefined;
        paddingEnd?: ResponsiveValue<string | number> | undefined;
    } & {
        readonly m?: ResponsiveValue<string | number> | undefined;
        readonly mt?: ResponsiveValue<string | number> | undefined;
        readonly mr?: ResponsiveValue<string | number> | undefined;
        readonly mb?: ResponsiveValue<string | number> | undefined;
        readonly ml?: ResponsiveValue<string | number> | undefined;
        readonly mx?: ResponsiveValue<string | number> | undefined;
        readonly my?: ResponsiveValue<string | number> | undefined;
        readonly ms?: ResponsiveValue<string | number> | undefined;
        readonly me?: ResponsiveValue<string | number> | undefined;
        readonly p?: ResponsiveValue<string | number> | undefined;
        readonly pt?: ResponsiveValue<string | number> | undefined;
        readonly pr?: ResponsiveValue<string | number> | undefined;
        readonly pb?: ResponsiveValue<string | number> | undefined;
        readonly pl?: ResponsiveValue<string | number> | undefined;
        readonly px?: ResponsiveValue<string | number> | undefined;
        readonly py?: ResponsiveValue<string | number> | undefined;
        readonly ps?: ResponsiveValue<string | number> | undefined;
        readonly pe?: ResponsiveValue<string | number> | undefined;
    } & {
        borderBottomWidth?: ResponsiveValue<number | undefined>;
        borderLeftWidth?: ResponsiveValue<number | undefined>;
        borderRightWidth?: ResponsiveValue<number | undefined>;
        borderStyle?: ResponsiveValue<"solid" | "dotted" | "dashed" | undefined>;
        borderTopWidth?: ResponsiveValue<number | undefined>;
        borderStartWidth?: ResponsiveValue<number | undefined>;
        borderEndWidth?: ResponsiveValue<number | undefined>;
        borderWidth?: ResponsiveValue<number | undefined>;
    } & {
        borderColor?: ResponsiveValue<PaletteColors> | undefined;
        borderTopColor?: ResponsiveValue<PaletteColors> | undefined;
        borderRightColor?: ResponsiveValue<PaletteColors> | undefined;
        borderLeftColor?: ResponsiveValue<PaletteColors> | undefined;
        borderBottomColor?: ResponsiveValue<PaletteColors> | undefined;
        borderStartColor?: ResponsiveValue<PaletteColors> | undefined;
        borderEndColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        borderRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomRightRadius?: ResponsiveValue<string | number> | undefined;
        borderTopLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderTopRightRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomStartRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomEndRadius?: ResponsiveValue<string | number> | undefined;
        borderTopStartRadius?: ResponsiveValue<string | number> | undefined;
        borderTopEndRadius?: ResponsiveValue<string | number> | undefined;
    } & {
        shadowOpacity?: ResponsiveValue<import("react-native").AnimatableNumericValue | undefined>;
        shadowOffset?: ResponsiveValue<Readonly<{
            width: number;
            height: number;
        }> | undefined>;
        shadowRadius?: ResponsiveValue<number | undefined>;
        elevation?: ResponsiveValue<number | undefined>;
    } & {
        boxShadow?: ResponsiveValue<string | number> | undefined;
        shadowColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        position?: ResponsiveValue<"absolute" | "relative" | undefined>;
        top?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        right?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        bottom?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        left?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        start?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        end?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & {
        zIndex?: ResponsiveValue<string | number> | undefined;
    }) | ((custom?: any) => Omit<import("moti").StyleValueWithReplacedTransforms<import("react-native").ViewStyle>, keyof import("react-native").ViewStyle> & Omit<import("react-native").ViewStyle, "p" | "ms" | "end" | "start" | "m" | "py" | "pl" | "elevation" | "margin" | "marginTop" | "marginRight" | "marginBottom" | "marginLeft" | "marginHorizontal" | "marginVertical" | "marginStart" | "marginEnd" | "padding" | "paddingTop" | "paddingRight" | "paddingBottom" | "paddingLeft" | "paddingHorizontal" | "paddingVertical" | "paddingStart" | "paddingEnd" | "width" | "height" | "minWidth" | "maxWidth" | "minHeight" | "maxHeight" | "mt" | "mr" | "mb" | "ml" | "mx" | "my" | "me" | "pt" | "pr" | "pb" | "px" | "ps" | "pe" | "overflow" | "aspectRatio" | "alignContent" | "alignItems" | "alignSelf" | "justifyContent" | "flex" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "w" | "h" | "minW" | "maxW" | "minH" | "maxH" | "transform" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "position" | "top" | "right" | "bottom" | "left" | "borderBottomWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStyle" | "borderTopWidth" | "borderStartWidth" | "borderEndWidth" | "borderWidth" | "borderColor" | "borderTopColor" | "borderRightColor" | "borderLeftColor" | "borderBottomColor" | "borderStartColor" | "borderEndColor" | "borderRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderBottomStartRadius" | "borderBottomEndRadius" | "borderTopStartRadius" | "borderTopEndRadius" | "shadowOpacity" | "shadowOffset" | "shadowRadius" | "opacity" | "zIndex" | "shadowColor" | keyof import("../../../theme").BackgroundColorProps | "visible" | "boxShadow"> & import("../../../theme").BackgroundColorProps & import("../../../theme").OpacityProps & import("../../../theme").VisibleProps & {
        width?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        height?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        overflow?: ResponsiveValue<"scroll" | "visible" | "hidden" | undefined>;
        aspectRatio?: ResponsiveValue<string | number | undefined>;
        alignContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>;
        alignItems?: ResponsiveValue<import("react-native").FlexAlignType | undefined>;
        alignSelf?: ResponsiveValue<"auto" | import("react-native").FlexAlignType | undefined>;
        justifyContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>;
        flex?: ResponsiveValue<number | undefined>;
        flexBasis?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        flexDirection?: ResponsiveValue<"row" | "column" | "row-reverse" | "column-reverse" | undefined>;
        flexGrow?: ResponsiveValue<number | undefined>;
        flexShrink?: ResponsiveValue<number | undefined>;
        flexWrap?: ResponsiveValue<"wrap" | "nowrap" | "wrap-reverse" | undefined>;
    } & {
        readonly w?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly h?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & import("../../../theme").TransformProps & {
        margin?: ResponsiveValue<string | number> | undefined;
        marginTop?: ResponsiveValue<string | number> | undefined;
        marginRight?: ResponsiveValue<string | number> | undefined;
        marginBottom?: ResponsiveValue<string | number> | undefined;
        marginLeft?: ResponsiveValue<string | number> | undefined;
        marginHorizontal?: ResponsiveValue<string | number> | undefined;
        marginVertical?: ResponsiveValue<string | number> | undefined;
        marginStart?: ResponsiveValue<string | number> | undefined;
        marginEnd?: ResponsiveValue<string | number> | undefined;
        padding?: ResponsiveValue<string | number> | undefined;
        paddingTop?: ResponsiveValue<string | number> | undefined;
        paddingRight?: ResponsiveValue<string | number> | undefined;
        paddingBottom?: ResponsiveValue<string | number> | undefined;
        paddingLeft?: ResponsiveValue<string | number> | undefined;
        paddingHorizontal?: ResponsiveValue<string | number> | undefined;
        paddingVertical?: ResponsiveValue<string | number> | undefined;
        paddingStart?: ResponsiveValue<string | number> | undefined;
        paddingEnd?: ResponsiveValue<string | number> | undefined;
    } & {
        readonly m?: ResponsiveValue<string | number> | undefined;
        readonly mt?: ResponsiveValue<string | number> | undefined;
        readonly mr?: ResponsiveValue<string | number> | undefined;
        readonly mb?: ResponsiveValue<string | number> | undefined;
        readonly ml?: ResponsiveValue<string | number> | undefined;
        readonly mx?: ResponsiveValue<string | number> | undefined;
        readonly my?: ResponsiveValue<string | number> | undefined;
        readonly ms?: ResponsiveValue<string | number> | undefined;
        readonly me?: ResponsiveValue<string | number> | undefined;
        readonly p?: ResponsiveValue<string | number> | undefined;
        readonly pt?: ResponsiveValue<string | number> | undefined;
        readonly pr?: ResponsiveValue<string | number> | undefined;
        readonly pb?: ResponsiveValue<string | number> | undefined;
        readonly pl?: ResponsiveValue<string | number> | undefined;
        readonly px?: ResponsiveValue<string | number> | undefined;
        readonly py?: ResponsiveValue<string | number> | undefined;
        readonly ps?: ResponsiveValue<string | number> | undefined;
        readonly pe?: ResponsiveValue<string | number> | undefined;
    } & {
        borderBottomWidth?: ResponsiveValue<number | undefined>;
        borderLeftWidth?: ResponsiveValue<number | undefined>;
        borderRightWidth?: ResponsiveValue<number | undefined>;
        borderStyle?: ResponsiveValue<"solid" | "dotted" | "dashed" | undefined>;
        borderTopWidth?: ResponsiveValue<number | undefined>;
        borderStartWidth?: ResponsiveValue<number | undefined>;
        borderEndWidth?: ResponsiveValue<number | undefined>;
        borderWidth?: ResponsiveValue<number | undefined>;
    } & {
        borderColor?: ResponsiveValue<PaletteColors> | undefined;
        borderTopColor?: ResponsiveValue<PaletteColors> | undefined;
        borderRightColor?: ResponsiveValue<PaletteColors> | undefined;
        borderLeftColor?: ResponsiveValue<PaletteColors> | undefined;
        borderBottomColor?: ResponsiveValue<PaletteColors> | undefined;
        borderStartColor?: ResponsiveValue<PaletteColors> | undefined;
        borderEndColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        borderRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomRightRadius?: ResponsiveValue<string | number> | undefined;
        borderTopLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderTopRightRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomStartRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomEndRadius?: ResponsiveValue<string | number> | undefined;
        borderTopStartRadius?: ResponsiveValue<string | number> | undefined;
        borderTopEndRadius?: ResponsiveValue<string | number> | undefined;
    } & {
        shadowOpacity?: ResponsiveValue<import("react-native").AnimatableNumericValue | undefined>;
        shadowOffset?: ResponsiveValue<Readonly<{
            width: number;
            height: number;
        }> | undefined>;
        shadowRadius?: ResponsiveValue<number | undefined>;
        elevation?: ResponsiveValue<number | undefined>;
    } & {
        boxShadow?: ResponsiveValue<string | number> | undefined;
        shadowColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        position?: ResponsiveValue<"absolute" | "relative" | undefined>;
        top?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        right?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        bottom?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        left?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        start?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        end?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & {
        zIndex?: ResponsiveValue<string | number> | undefined;
    }) | undefined;
    transition?: import("moti").MotiTransitionProp<Omit<import("moti").StyleValueWithReplacedTransforms<import("react-native").ViewStyle>, keyof import("react-native").ViewStyle> & Omit<import("react-native").ViewStyle, "p" | "ms" | "end" | "start" | "m" | "py" | "pl" | "elevation" | "margin" | "marginTop" | "marginRight" | "marginBottom" | "marginLeft" | "marginHorizontal" | "marginVertical" | "marginStart" | "marginEnd" | "padding" | "paddingTop" | "paddingRight" | "paddingBottom" | "paddingLeft" | "paddingHorizontal" | "paddingVertical" | "paddingStart" | "paddingEnd" | "width" | "height" | "minWidth" | "maxWidth" | "minHeight" | "maxHeight" | "mt" | "mr" | "mb" | "ml" | "mx" | "my" | "me" | "pt" | "pr" | "pb" | "px" | "ps" | "pe" | "overflow" | "aspectRatio" | "alignContent" | "alignItems" | "alignSelf" | "justifyContent" | "flex" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "w" | "h" | "minW" | "maxW" | "minH" | "maxH" | "transform" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "position" | "top" | "right" | "bottom" | "left" | "borderBottomWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStyle" | "borderTopWidth" | "borderStartWidth" | "borderEndWidth" | "borderWidth" | "borderColor" | "borderTopColor" | "borderRightColor" | "borderLeftColor" | "borderBottomColor" | "borderStartColor" | "borderEndColor" | "borderRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderBottomStartRadius" | "borderBottomEndRadius" | "borderTopStartRadius" | "borderTopEndRadius" | "shadowOpacity" | "shadowOffset" | "shadowRadius" | "opacity" | "zIndex" | "shadowColor" | keyof import("../../../theme").BackgroundColorProps | "visible" | "boxShadow"> & import("../../../theme").BackgroundColorProps & import("../../../theme").OpacityProps & import("../../../theme").VisibleProps & {
        width?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        height?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        overflow?: ResponsiveValue<"scroll" | "visible" | "hidden" | undefined>;
        aspectRatio?: ResponsiveValue<string | number | undefined>;
        alignContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>;
        alignItems?: ResponsiveValue<import("react-native").FlexAlignType | undefined>;
        alignSelf?: ResponsiveValue<"auto" | import("react-native").FlexAlignType | undefined>;
        justifyContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>;
        flex?: ResponsiveValue<number | undefined>;
        flexBasis?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        flexDirection?: ResponsiveValue<"row" | "column" | "row-reverse" | "column-reverse" | undefined>;
        flexGrow?: ResponsiveValue<number | undefined>;
        flexShrink?: ResponsiveValue<number | undefined>;
        flexWrap?: ResponsiveValue<"wrap" | "nowrap" | "wrap-reverse" | undefined>;
    } & {
        readonly w?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly h?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & import("../../../theme").TransformProps & {
        margin?: ResponsiveValue<string | number> | undefined;
        marginTop?: ResponsiveValue<string | number> | undefined;
        marginRight?: ResponsiveValue<string | number> | undefined;
        marginBottom?: ResponsiveValue<string | number> | undefined;
        marginLeft?: ResponsiveValue<string | number> | undefined;
        marginHorizontal?: ResponsiveValue<string | number> | undefined;
        marginVertical?: ResponsiveValue<string | number> | undefined;
        marginStart?: ResponsiveValue<string | number> | undefined;
        marginEnd?: ResponsiveValue<string | number> | undefined;
        padding?: ResponsiveValue<string | number> | undefined;
        paddingTop?: ResponsiveValue<string | number> | undefined;
        paddingRight?: ResponsiveValue<string | number> | undefined;
        paddingBottom?: ResponsiveValue<string | number> | undefined;
        paddingLeft?: ResponsiveValue<string | number> | undefined;
        paddingHorizontal?: ResponsiveValue<string | number> | undefined;
        paddingVertical?: ResponsiveValue<string | number> | undefined;
        paddingStart?: ResponsiveValue<string | number> | undefined;
        paddingEnd?: ResponsiveValue<string | number> | undefined;
    } & {
        readonly m?: ResponsiveValue<string | number> | undefined;
        readonly mt?: ResponsiveValue<string | number> | undefined;
        readonly mr?: ResponsiveValue<string | number> | undefined;
        readonly mb?: ResponsiveValue<string | number> | undefined;
        readonly ml?: ResponsiveValue<string | number> | undefined;
        readonly mx?: ResponsiveValue<string | number> | undefined;
        readonly my?: ResponsiveValue<string | number> | undefined;
        readonly ms?: ResponsiveValue<string | number> | undefined;
        readonly me?: ResponsiveValue<string | number> | undefined;
        readonly p?: ResponsiveValue<string | number> | undefined;
        readonly pt?: ResponsiveValue<string | number> | undefined;
        readonly pr?: ResponsiveValue<string | number> | undefined;
        readonly pb?: ResponsiveValue<string | number> | undefined;
        readonly pl?: ResponsiveValue<string | number> | undefined;
        readonly px?: ResponsiveValue<string | number> | undefined;
        readonly py?: ResponsiveValue<string | number> | undefined;
        readonly ps?: ResponsiveValue<string | number> | undefined;
        readonly pe?: ResponsiveValue<string | number> | undefined;
    } & {
        borderBottomWidth?: ResponsiveValue<number | undefined>;
        borderLeftWidth?: ResponsiveValue<number | undefined>;
        borderRightWidth?: ResponsiveValue<number | undefined>;
        borderStyle?: ResponsiveValue<"solid" | "dotted" | "dashed" | undefined>;
        borderTopWidth?: ResponsiveValue<number | undefined>;
        borderStartWidth?: ResponsiveValue<number | undefined>;
        borderEndWidth?: ResponsiveValue<number | undefined>;
        borderWidth?: ResponsiveValue<number | undefined>;
    } & {
        borderColor?: ResponsiveValue<PaletteColors> | undefined;
        borderTopColor?: ResponsiveValue<PaletteColors> | undefined;
        borderRightColor?: ResponsiveValue<PaletteColors> | undefined;
        borderLeftColor?: ResponsiveValue<PaletteColors> | undefined;
        borderBottomColor?: ResponsiveValue<PaletteColors> | undefined;
        borderStartColor?: ResponsiveValue<PaletteColors> | undefined;
        borderEndColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        borderRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomRightRadius?: ResponsiveValue<string | number> | undefined;
        borderTopLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderTopRightRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomStartRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomEndRadius?: ResponsiveValue<string | number> | undefined;
        borderTopStartRadius?: ResponsiveValue<string | number> | undefined;
        borderTopEndRadius?: ResponsiveValue<string | number> | undefined;
    } & {
        shadowOpacity?: ResponsiveValue<import("react-native").AnimatableNumericValue | undefined>;
        shadowOffset?: ResponsiveValue<Readonly<{
            width: number;
            height: number;
        }> | undefined>;
        shadowRadius?: ResponsiveValue<number | undefined>;
        elevation?: ResponsiveValue<number | undefined>;
    } & {
        boxShadow?: ResponsiveValue<string | number> | undefined;
        shadowColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        position?: ResponsiveValue<"absolute" | "relative" | undefined>;
        top?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        right?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        bottom?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        left?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        start?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        end?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & {
        zIndex?: ResponsiveValue<string | number> | undefined;
    }> | undefined;
    exitTransition?: import("moti").MotiTransitionProp<Omit<import("moti").StyleValueWithReplacedTransforms<import("react-native").ViewStyle>, keyof import("react-native").ViewStyle> & Omit<import("react-native").ViewStyle, "p" | "ms" | "end" | "start" | "m" | "py" | "pl" | "elevation" | "margin" | "marginTop" | "marginRight" | "marginBottom" | "marginLeft" | "marginHorizontal" | "marginVertical" | "marginStart" | "marginEnd" | "padding" | "paddingTop" | "paddingRight" | "paddingBottom" | "paddingLeft" | "paddingHorizontal" | "paddingVertical" | "paddingStart" | "paddingEnd" | "width" | "height" | "minWidth" | "maxWidth" | "minHeight" | "maxHeight" | "mt" | "mr" | "mb" | "ml" | "mx" | "my" | "me" | "pt" | "pr" | "pb" | "px" | "ps" | "pe" | "overflow" | "aspectRatio" | "alignContent" | "alignItems" | "alignSelf" | "justifyContent" | "flex" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "w" | "h" | "minW" | "maxW" | "minH" | "maxH" | "transform" | "transformMatrix" | "rotation" | "scaleX" | "scaleY" | "translateX" | "translateY" | "position" | "top" | "right" | "bottom" | "left" | "borderBottomWidth" | "borderLeftWidth" | "borderRightWidth" | "borderStyle" | "borderTopWidth" | "borderStartWidth" | "borderEndWidth" | "borderWidth" | "borderColor" | "borderTopColor" | "borderRightColor" | "borderLeftColor" | "borderBottomColor" | "borderStartColor" | "borderEndColor" | "borderRadius" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderBottomStartRadius" | "borderBottomEndRadius" | "borderTopStartRadius" | "borderTopEndRadius" | "shadowOpacity" | "shadowOffset" | "shadowRadius" | "opacity" | "zIndex" | "shadowColor" | keyof import("../../../theme").BackgroundColorProps | "visible" | "boxShadow"> & import("../../../theme").BackgroundColorProps & import("../../../theme").OpacityProps & import("../../../theme").VisibleProps & {
        width?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        height?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxWidth?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        minHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        maxHeight?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        overflow?: ResponsiveValue<"scroll" | "visible" | "hidden" | undefined>;
        aspectRatio?: ResponsiveValue<string | number | undefined>;
        alignContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "stretch" | "space-between" | "space-around" | undefined>;
        alignItems?: ResponsiveValue<import("react-native").FlexAlignType | undefined>;
        alignSelf?: ResponsiveValue<"auto" | import("react-native").FlexAlignType | undefined>;
        justifyContent?: ResponsiveValue<"center" | "flex-start" | "flex-end" | "space-between" | "space-around" | "space-evenly" | undefined>;
        flex?: ResponsiveValue<number | undefined>;
        flexBasis?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        flexDirection?: ResponsiveValue<"row" | "column" | "row-reverse" | "column-reverse" | undefined>;
        flexGrow?: ResponsiveValue<number | undefined>;
        flexShrink?: ResponsiveValue<number | undefined>;
        flexWrap?: ResponsiveValue<"wrap" | "nowrap" | "wrap-reverse" | undefined>;
    } & {
        readonly w?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly h?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxW?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly minH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        readonly maxH?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & import("../../../theme").TransformProps & {
        margin?: ResponsiveValue<string | number> | undefined;
        marginTop?: ResponsiveValue<string | number> | undefined;
        marginRight?: ResponsiveValue<string | number> | undefined;
        marginBottom?: ResponsiveValue<string | number> | undefined;
        marginLeft?: ResponsiveValue<string | number> | undefined;
        marginHorizontal?: ResponsiveValue<string | number> | undefined;
        marginVertical?: ResponsiveValue<string | number> | undefined;
        marginStart?: ResponsiveValue<string | number> | undefined;
        marginEnd?: ResponsiveValue<string | number> | undefined;
        padding?: ResponsiveValue<string | number> | undefined;
        paddingTop?: ResponsiveValue<string | number> | undefined;
        paddingRight?: ResponsiveValue<string | number> | undefined;
        paddingBottom?: ResponsiveValue<string | number> | undefined;
        paddingLeft?: ResponsiveValue<string | number> | undefined;
        paddingHorizontal?: ResponsiveValue<string | number> | undefined;
        paddingVertical?: ResponsiveValue<string | number> | undefined;
        paddingStart?: ResponsiveValue<string | number> | undefined;
        paddingEnd?: ResponsiveValue<string | number> | undefined;
    } & {
        readonly m?: ResponsiveValue<string | number> | undefined;
        readonly mt?: ResponsiveValue<string | number> | undefined;
        readonly mr?: ResponsiveValue<string | number> | undefined;
        readonly mb?: ResponsiveValue<string | number> | undefined;
        readonly ml?: ResponsiveValue<string | number> | undefined;
        readonly mx?: ResponsiveValue<string | number> | undefined;
        readonly my?: ResponsiveValue<string | number> | undefined;
        readonly ms?: ResponsiveValue<string | number> | undefined;
        readonly me?: ResponsiveValue<string | number> | undefined;
        readonly p?: ResponsiveValue<string | number> | undefined;
        readonly pt?: ResponsiveValue<string | number> | undefined;
        readonly pr?: ResponsiveValue<string | number> | undefined;
        readonly pb?: ResponsiveValue<string | number> | undefined;
        readonly pl?: ResponsiveValue<string | number> | undefined;
        readonly px?: ResponsiveValue<string | number> | undefined;
        readonly py?: ResponsiveValue<string | number> | undefined;
        readonly ps?: ResponsiveValue<string | number> | undefined;
        readonly pe?: ResponsiveValue<string | number> | undefined;
    } & {
        borderBottomWidth?: ResponsiveValue<number | undefined>;
        borderLeftWidth?: ResponsiveValue<number | undefined>;
        borderRightWidth?: ResponsiveValue<number | undefined>;
        borderStyle?: ResponsiveValue<"solid" | "dotted" | "dashed" | undefined>;
        borderTopWidth?: ResponsiveValue<number | undefined>;
        borderStartWidth?: ResponsiveValue<number | undefined>;
        borderEndWidth?: ResponsiveValue<number | undefined>;
        borderWidth?: ResponsiveValue<number | undefined>;
    } & {
        borderColor?: ResponsiveValue<PaletteColors> | undefined;
        borderTopColor?: ResponsiveValue<PaletteColors> | undefined;
        borderRightColor?: ResponsiveValue<PaletteColors> | undefined;
        borderLeftColor?: ResponsiveValue<PaletteColors> | undefined;
        borderBottomColor?: ResponsiveValue<PaletteColors> | undefined;
        borderStartColor?: ResponsiveValue<PaletteColors> | undefined;
        borderEndColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        borderRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomRightRadius?: ResponsiveValue<string | number> | undefined;
        borderTopLeftRadius?: ResponsiveValue<string | number> | undefined;
        borderTopRightRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomStartRadius?: ResponsiveValue<string | number> | undefined;
        borderBottomEndRadius?: ResponsiveValue<string | number> | undefined;
        borderTopStartRadius?: ResponsiveValue<string | number> | undefined;
        borderTopEndRadius?: ResponsiveValue<string | number> | undefined;
    } & {
        shadowOpacity?: ResponsiveValue<import("react-native").AnimatableNumericValue | undefined>;
        shadowOffset?: ResponsiveValue<Readonly<{
            width: number;
            height: number;
        }> | undefined>;
        shadowRadius?: ResponsiveValue<number | undefined>;
        elevation?: ResponsiveValue<number | undefined>;
    } & {
        boxShadow?: ResponsiveValue<string | number> | undefined;
        shadowColor?: ResponsiveValue<PaletteColors> | undefined;
    } & {
        position?: ResponsiveValue<"absolute" | "relative" | undefined>;
        top?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        right?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        bottom?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        left?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        start?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
        end?: ResponsiveValue<import("react-native").DimensionValue | undefined>;
    } & {
        zIndex?: ResponsiveValue<string | number> | undefined;
    }> | undefined;
    state?: Pick<import("moti").UseAnimationState<any>, "__state"> | undefined;
}> & {
    colorScheme?: string | undefined;
} & {
    size?: ResponsiveValue<string> | undefined;
    variant?: ResponsiveValue<string> | undefined;
} & {
    children?: React.ReactNode | JSX.Element | JSX.Element[];
}, "ref"> & React.RefAttributes<unknown>>>;
export type SkeletonProps = React.ComponentProps<typeof Skeleton>;
export default Skeleton;
//# sourceMappingURL=skeleton.d.ts.map